/*
 * cslr_sys_001.h
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef _CSLR__SYS_9_H_
#define _CSLR__SYS_9_H_

#include <cslr.h>

#include <tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct {
    volatile Uint32 _PINMUX0;
    volatile Uint32 _PINMUX1;
    volatile Uint32 _DSPBOOTADDR;
    volatile Uint32 SUSPSRC;
    volatile Uint32 BOOTSTAT;
    volatile Uint32 _BOOTCFG;
    volatile Uint32 SMTREFLEX;
    volatile Uint8 RSVD0[4];
    volatile Uint32 DDR_SLEW;
    volatile Uint32 ARMBOOT;
    volatile Uint32 DEVICE_ID;
    volatile Uint32 IMCOPBOOT;
    volatile Uint32 UHPI_CTRL;
    volatile Uint32 USB_PHY_CTRL;
    volatile Uint32 VIDCLKCTL;
    volatile Uint32 MSTPRI0;
    volatile Uint32 MSTPRI1;
    volatile Uint32 MSTPRI2;
    volatile Uint32 VDD3P3VPWDN;
    volatile Uint32 DFTENABLE;
    volatile Uint32 SPIOCTL;
    volatile Uint32 PWMCTL;
    volatile Uint32 TPTCCFG;
    volatile Uint32 CLKCTL;
    volatile Uint32 DSPINT;
    volatile Uint32 DSPINTSET;
    volatile Uint32 DSPINTCLR;
    volatile Uint32 VSCLKDIS;
    volatile Uint32 ARMINT;
    volatile Uint32 ARMINTSET;
    volatile Uint32 ARMINTCLR;
    volatile Uint32 ARMWAIT;
    volatile Uint32 SEC_PSEUDO0;
    volatile Uint32 SEC_PSEUDO1;
} CSL_SysRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PINMUX0 */

#define CSL_SYS_PINMUX0_VBUSDIS_MASK (0x80000000u)
#define CSL_SYS_PINMUX0_VBUSDIS_SHIFT (0x0000001Fu)
#define CSL_SYS_PINMUX0_VBUSDIS_RESETVAL (0x00000000u)
/*----VBUSDIS Tokens----*/
#define CSL_SYS_PINMUX0_VBUSDIS_USB_DRVVBUS (0x00000000u)
#define CSL_SYS_PINMUX0_VBUSDIS_GP22 (0x00000001u)

#define CSL_SYS_PINMUX0_STCCK_MASK (0x40000000u)
#define CSL_SYS_PINMUX0_STCCK_SHIFT (0x0000001Eu)
#define CSL_SYS_PINMUX0_STCCK_RESETVAL (0x00000000u)
/*----STCCK Tokens----*/
#define CSL_SYS_PINMUX0_STCCK_GP04_INT04 (0x00000000u)
#define CSL_SYS_PINMUX0_STCCK_STCSRC_CLKIN (0x00000001u)

#define CSL_SYS_PINMUX0_AUDCK1_MASK (0x20000000u)
#define CSL_SYS_PINMUX0_AUDCK1_SHIFT (0x0000001Du)
#define CSL_SYS_PINMUX0_AUDCK1_RESETVAL (0x00000000u)
/*----AUDCK1 Tokens----*/
#define CSL_SYS_PINMUX0_AUDCK1_GP02_INT02 (0x00000000u)
#define CSL_SYS_PINMUX0_AUDCK1_ENABLE (0x00000001u)

#define CSL_SYS_PINMUX0_AUDCK0_MASK (0x10000000u)
#define CSL_SYS_PINMUX0_AUDCK0_SHIFT (0x0000001Cu)
#define CSL_SYS_PINMUX0_AUDCK0_RESETVAL (0x00000000u)
/*----AUDCK0 Tokens----*/
#define CSL_SYS_PINMUX0_AUDCK0_GP03_INT03 (0x00000000u)
#define CSL_SYS_PINMUX0_AUDCK0_ENABLE (0x00000001u)


#define CSL_SYS_PINMUX0_CRGMUX_MASK (0x07000000u)
#define CSL_SYS_PINMUX0_CRGMUX_SHIFT (0x00000018u)
#define CSL_SYS_PINMUX0_CRGMUX_RESETVAL (0x00000000u)
/*----CRGMUX Tokens----*/
#define CSL_SYS_PINMUX0_CRGMUX_NOCRGEN (0x00000000u)
#define CSL_SYS_PINMUX0_CRGMUX_CRGEN1_MUXWITH_UART2DATA (0x00000001u)
#define CSL_SYS_PINMUX0_CRGMUX_CRGEN0_MUXWITH_PWM0 (0x00000004u)
#define CSL_SYS_PINMUX0_CRGMUX_CRGEN0_CRGEN1 (0x00000005u)
#define CSL_SYS_PINMUX0_CRGMUX_CRGEN0_MUXWITH_UART2DATA (0x00000006u)

#define CSL_SYS_PINMUX0_STSOMUX_MASK (0x00C00000u)
#define CSL_SYS_PINMUX0_STSOMUX_SHIFT (0x00000016u)
#define CSL_SYS_PINMUX0_STSOMUX_RESETVAL (0x00000000u)
/*----STSOMUX Tokens----*/
#define CSL_SYS_PINMUX0_STSOMUX_NOSTSO (0x00000000u)
#define CSL_SYS_PINMUX0_STSOMUX_ENABLE_MUXWITH_VPIF_DOUT (0x00000002u)
#define CSL_SYS_PINMUX0_STSOMUX_ENABLE_MUXWITH_UART_PWM (0x00000003u)

#define CSL_SYS_PINMUX0_STSIMUX_MASK (0x00300000u)
#define CSL_SYS_PINMUX0_STSIMUX_SHIFT (0x00000014u)
#define CSL_SYS_PINMUX0_STSIMUX_RESETVAL (0x00000000u)
/*----STSIMUX Tokens----*/
#define CSL_SYS_PINMUX0_STSIMUX_NOSTSI (0x00000000u)
#define CSL_SYS_PINMUX0_STSIMUX_ENABLE_MUXWITH_UART0 (0x00000001u)
#define CSL_SYS_PINMUX0_STSIMUX_ENABLE_MUXWITH_VPIF_DOUT (0x00000002u)
#define CSL_SYS_PINMUX0_STSIMUX_ENABLE_MUXWITH_VPIF_DIN (0x00000003u)

#define CSL_SYS_PINMUX0_PTSOMUX_MASK (0x000C0000u)
#define CSL_SYS_PINMUX0_PTSOMUX_SHIFT (0x00000012u)
#define CSL_SYS_PINMUX0_PTSOMUX_RESETVAL (0x00000000u)
/*----PTSOMUX Tokens----*/
#define CSL_SYS_PINMUX0_PTSOMUX_NOPTSO (0x00000000u)
#define CSL_SYS_PINMUX0_PTSOMUX_NOPTSO1 (0x00000001u)
#define CSL_SYS_PINMUX0_PTSOMUX_ENABLE_MUX_VPIF_DIN (0x00000002u)
#define CSL_SYS_PINMUX0_PTSOMUX_ENABLE_MUX_UART1 (0x00000003u)

#define CSL_SYS_PINMUX0_PTSIMUX_MASK (0x00030000u)
#define CSL_SYS_PINMUX0_PTSIMUX_SHIFT (0x00000010u)
#define CSL_SYS_PINMUX0_PTSIMUX_RESETVAL (0x00000000u)
/*----PTSIMUX Tokens----*/
#define CSL_SYS_PINMUX0_PTSIMUX_NOPTSI (0x00000000u)
#define CSL_SYS_PINMUX0_PTSIMUX_NOPTSI1 (0x00000001u)
#define CSL_SYS_PINMUX0_PTSIMUX_ENABLE_MUX_VPIF_DIN (0x00000002u)
#define CSL_SYS_PINMUX0_PTSIMUX_ENABLE_MUX_UART1 (0x00000003u)


#define CSL_SYS_PINMUX0_PINTD_MASK (0x00000020u)
#define CSL_SYS_PINMUX0_PINTD_SHIFT (0x00000005u)
#define CSL_SYS_PINMUX0_PINTD_RESETVAL (0x00000000u)
/*----PINTD Tokens----*/
#define CSL_SYS_PINMUX0_PINTD_GP05_INT05_FUN (0x00000000u)
#define CSL_SYS_PINMUX0_PINTD_PCI_INTD_FUN (0x00000001u)


#define CSL_SYS_PINMUX0_PCIEN_MASK (0x00000004u)
#define CSL_SYS_PINMUX0_PCIEN_SHIFT (0x00000002u)
#define CSL_SYS_PINMUX0_PCIEN_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_HPIEN_MASK (0x00000002u)
#define CSL_SYS_PINMUX0_HPIEN_SHIFT (0x00000001u)
#define CSL_SYS_PINMUX0_HPIEN_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_ATAEN_MASK (0x00000001u)
#define CSL_SYS_PINMUX0_ATAEN_SHIFT (0x00000000u)
#define CSL_SYS_PINMUX0_ATAEN_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_RESETVAL (0x00000000u)

/* PINMUX1 */


#define CSL_SYS_PINMUX1_UART2CTL_MASK (0x00000030u)
#define CSL_SYS_PINMUX1_UART2CTL_SHIFT (0x00000004u)
#define CSL_SYS_PINMUX1_UART2CTL_RESETVAL (0x00000000u)
/*----UART2CTL Tokens----*/
#define CSL_SYS_PINMUX1_UART2CTL_UART_WITH_FLOW (0x00000000u)
#define CSL_SYS_PINMUX1_UART2CTL_UART_WITHOUT_FLOW (0x00000001u)
#define CSL_SYS_PINMUX1_UART2CTL_IRDA_CIR (0x00000002u)
#define CSL_SYS_PINMUX1_UART2CTL_GPIO (0x00000003u)

#define CSL_SYS_PINMUX1_UART1CTL_MASK (0x0000000Cu)
#define CSL_SYS_PINMUX1_UART1CTL_SHIFT (0x00000002u)
#define CSL_SYS_PINMUX1_UART1CTL_RESETVAL (0x00000000u)
/*----UART1CTL Tokens----*/
#define CSL_SYS_PINMUX1_UART1CTL_UART_WITH_FLOW (0x00000000u)
#define CSL_SYS_PINMUX1_UART1CTL_UART_WITHOUT_FLOW (0x00000001u)
#define CSL_SYS_PINMUX1_UART1CTL_IRDA_CIR (0x00000002u)
#define CSL_SYS_PINMUX1_UART1CTL_GPIO (0x00000003u)

#define CSL_SYS_PINMUX1_UART0CTL_MASK (0x00000003u)
#define CSL_SYS_PINMUX1_UART0CTL_SHIFT (0x00000000u)
#define CSL_SYS_PINMUX1_UART0CTL_RESETVAL (0x00000000u)
/*----UART0CTL Tokens----*/
#define CSL_SYS_PINMUX1_UART0CTL_UART_WITH_MODEM (0x00000000u)
#define CSL_SYS_PINMUX1_UART0CTL_UART_WITHOUT_MODEM (0x00000001u)
#define CSL_SYS_PINMUX1_UART0CTL_IRDA_CIR (0x00000002u)

#define CSL_SYS_PINMUX1_RESETVAL (0x00000000u)

/* DSPBOOTADDR */

#define CSL_SYS_DSPBOOTADDR_BOOTADDR_MASK (0xFFFFFFFFu)
#define CSL_SYS_DSPBOOTADDR_BOOTADDR_SHIFT (0x00000000u)
#define CSL_SYS_DSPBOOTADDR_BOOTADDR_RESETVAL (0x42200000u)

#define CSL_SYS_DSPBOOTADDR_RESETVAL (0x42200000u)

/* SUSPSRC */

#define CSL_SYS_SUSPSRC_CRGEN1SRC_MASK (0x80000000u)
#define CSL_SYS_SUSPSRC_CRGEN1SRC_SHIFT (0x0000001Fu)
#define CSL_SYS_SUSPSRC_CRGEN1SRC_RESETVAL (0x00000000u)
/*----CRGEN1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_CRGEN1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_CRGEN1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_CRGEN0SRC_MASK (0x40000000u)
#define CSL_SYS_SUSPSRC_CRGEN0SRC_SHIFT (0x0000001Eu)
#define CSL_SYS_SUSPSRC_CRGEN0SRC_RESETVAL (0x00000000u)
/*----CRGEN0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_CRGEN0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_CRGEN0SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_TIMR2SRC_MASK (0x20000000u)
#define CSL_SYS_SUSPSRC_TIMR2SRC_SHIFT (0x0000001Du)
#define CSL_SYS_SUSPSRC_TIMR2SRC_RESETVAL (0x00000000u)
/*----TIMR2SRC Tokens----*/
#define CSL_SYS_SUSPSRC_TIMR2SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_TIMR2SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_TIMR1SRC_MASK (0x10000000u)
#define CSL_SYS_SUSPSRC_TIMR1SRC_SHIFT (0x0000001Cu)
#define CSL_SYS_SUSPSRC_TIMR1SRC_RESETVAL (0x00000000u)
/*----TIMR1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_TIMR1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_TIMR1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_TIMR0SRC_MASK (0x08000000u)
#define CSL_SYS_SUSPSRC_TIMR0SRC_SHIFT (0x0000001Bu)
#define CSL_SYS_SUSPSRC_TIMR0SRC_RESETVAL (0x00000000u)
/*----TIMR0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_TIMR0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_TIMR0SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_GPIOSRC_MASK (0x04000000u)
#define CSL_SYS_SUSPSRC_GPIOSRC_SHIFT (0x0000001Au)
#define CSL_SYS_SUSPSRC_GPIOSRC_RESETVAL (0x00000000u)
/*----GPIOSRC Tokens----*/
#define CSL_SYS_SUSPSRC_GPIOSRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_GPIOSRC_GEMEMU (0x00000001u)


#define CSL_SYS_SUSPSRC_PWM1SRC_MASK (0x01000000u)
#define CSL_SYS_SUSPSRC_PWM1SRC_SHIFT (0x00000018u)
#define CSL_SYS_SUSPSRC_PWM1SRC_RESETVAL (0x00000000u)
/*----PWM1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_PWM1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_PWM1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_PWM0SRC_MASK (0x00800000u)
#define CSL_SYS_SUSPSRC_PWM0SRC_SHIFT (0x00000017u)
#define CSL_SYS_SUSPSRC_PWM0SRC_RESETVAL (0x00000000u)
/*----PWM0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_PWM0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_PWM0SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_SPISRC_MASK (0x00400000u)
#define CSL_SYS_SUSPSRC_SPISRC_SHIFT (0x00000016u)
#define CSL_SYS_SUSPSRC_SPISRC_RESETVAL (0x00000000u)
/*----SPISRC Tokens----*/
#define CSL_SYS_SUSPSRC_SPISRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_SPISRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_UART2SRC_MASK (0x00200000u)
#define CSL_SYS_SUSPSRC_UART2SRC_SHIFT (0x00000015u)
#define CSL_SYS_SUSPSRC_UART2SRC_RESETVAL (0x00000000u)
/*----UART2SRC Tokens----*/
#define CSL_SYS_SUSPSRC_UART2SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_UART2SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_UART1SRC_MASK (0x00100000u)
#define CSL_SYS_SUSPSRC_UART1SRC_SHIFT (0x00000014u)
#define CSL_SYS_SUSPSRC_UART1SRC_RESETVAL (0x00000000u)
/*----UART1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_UART1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_UART1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_UART0SRC_MASK (0x00080000u)
#define CSL_SYS_SUSPSRC_UART0SRC_SHIFT (0x00000013u)
#define CSL_SYS_SUSPSRC_UART0SRC_RESETVAL (0x00000000u)
/*----UART0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_UART0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_UART0SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_I2CSRC_MASK (0x00040000u)
#define CSL_SYS_SUSPSRC_I2CSRC_SHIFT (0x00000012u)
#define CSL_SYS_SUSPSRC_I2CSRC_RESETVAL (0x00000000u)
/*----I2CSRC Tokens----*/
#define CSL_SYS_SUSPSRC_I2CSRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_I2CSRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_MCASP1SRC_MASK (0x00020000u)
#define CSL_SYS_SUSPSRC_MCASP1SRC_SHIFT (0x00000011u)
#define CSL_SYS_SUSPSRC_MCASP1SRC_RESETVAL (0x00000000u)
/*----MCASP1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_MCASP1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_MCASP1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_MCASP0SRC_MASK (0x00010000u)
#define CSL_SYS_SUSPSRC_MCASP0SRC_SHIFT (0x00000010u)
#define CSL_SYS_SUSPSRC_MCASP0SRC_RESETVAL (0x00000000u)
/*----MCASP0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_MCASP0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_MCASP0SRC_GEMEMU (0x00000001u)


#define CSL_SYS_SUSPSRC_UHPISRC_MASK (0x00001000u)
#define CSL_SYS_SUSPSRC_UHPISRC_SHIFT (0x0000000Cu)
#define CSL_SYS_SUSPSRC_UHPISRC_RESETVAL (0x00000000u)
/*----UHPISRC Tokens----*/
#define CSL_SYS_SUSPSRC_UHPISRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_UHPISRC_GEMEMU (0x00000001u)


#define CSL_SYS_SUSPSRC_GMACSRC_MASK (0x00000400u)
#define CSL_SYS_SUSPSRC_GMACSRC_SHIFT (0x0000000Au)
#define CSL_SYS_SUSPSRC_GMACSRC_RESETVAL (0x00000000u)
/*----GMACSRC Tokens----*/
#define CSL_SYS_SUSPSRC_GMACSRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_GMACSRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_USBSRC_MASK (0x00000200u)
#define CSL_SYS_SUSPSRC_USBSRC_SHIFT (0x00000009u)
#define CSL_SYS_SUSPSRC_USBSRC_RESETVAL (0x00000000u)
/*----USBSRC Tokens----*/
#define CSL_SYS_SUSPSRC_USBSRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_USBSRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_GESRC_MASK (0x00000100u)
#define CSL_SYS_SUSPSRC_GESRC_SHIFT (0x00000008u)
#define CSL_SYS_SUSPSRC_GESRC_RESETVAL (0x00000000u)
/*----GESRC Tokens----*/
#define CSL_SYS_SUSPSRC_GESRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_GESRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_SPIO1SRC_MASK (0x00000080u)
#define CSL_SYS_SUSPSRC_SPIO1SRC_SHIFT (0x00000007u)
#define CSL_SYS_SUSPSRC_SPIO1SRC_RESETVAL (0x00000000u)
/*----SPIO1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_SPIO1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_SPIO1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_SPIO0SRC_MASK (0x00000040u)
#define CSL_SYS_SUSPSRC_SPIO0SRC_SHIFT (0x00000006u)
#define CSL_SYS_SUSPSRC_SPIO0SRC_RESETVAL (0x00000000u)
/*----SPIO0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_SPIO0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_SPIO0SRC_GEMEMU (0x00000001u)


#define CSL_SYS_SUSPSRC_VPIFSRC_MASK (0x00000010u)
#define CSL_SYS_SUSPSRC_VPIFSRC_SHIFT (0x00000004u)
#define CSL_SYS_SUSPSRC_VPIFSRC_RESETVAL (0x00000000u)
/*----VPIFSRC Tokens----*/
#define CSL_SYS_SUSPSRC_VPIFSRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_VPIFSRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_IMCOP1SRC_MASK (0x00000008u)
#define CSL_SYS_SUSPSRC_IMCOP1SRC_SHIFT (0x00000003u)
#define CSL_SYS_SUSPSRC_IMCOP1SRC_RESETVAL (0x00000000u)
/*----IMCOP1SRC Tokens----*/
#define CSL_SYS_SUSPSRC_IMCOP1SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_IMCOP1SRC_GEMEMU (0x00000001u)

#define CSL_SYS_SUSPSRC_IMCOP0SRC_MASK (0x00000004u)
#define CSL_SYS_SUSPSRC_IMCOP0SRC_SHIFT (0x00000002u)
#define CSL_SYS_SUSPSRC_IMCOP0SRC_RESETVAL (0x00000000u)
/*----IMCOP0SRC Tokens----*/
#define CSL_SYS_SUSPSRC_IMCOP0SRC_ARMEMU (0x00000000u)
#define CSL_SYS_SUSPSRC_IMCOP0SRC_GEMEMU (0x00000001u)


#define CSL_SYS_SUSPSRC_RESETVAL (0x00000000u)

/* BOOTSTAT */

#define CSL_SYS_BOOTSTAT_WDRST_MASK (0x80000000u)
#define CSL_SYS_BOOTSTAT_WDRST_SHIFT (0x0000001Fu)
#define CSL_SYS_BOOTSTAT_WDRST_RESETVAL (0x00000000u)
/*----WDRST Tokens----*/
#define CSL_SYS_BOOTSTAT_WDRST_NOTIMEOUT (0x00000000u)
#define CSL_SYS_BOOTSTAT_WDRST_TIMEOUT (0x00000001u)


#define CSL_SYS_BOOTSTAT_BOOTERR_MASK (0x000F0000u)
#define CSL_SYS_BOOTSTAT_BOOTERR_SHIFT (0x00000010u)
#define CSL_SYS_BOOTSTAT_BOOTERR_RESETVAL (0x00000000u)
/*----BOOTERR Tokens----*/
#define CSL_SYS_BOOTSTAT_BOOTERR_NOERROR (0x00000000u)


#define CSL_SYS_BOOTSTAT_BC_MASK (0x00000001u)
#define CSL_SYS_BOOTSTAT_BC_SHIFT (0x00000000u)
#define CSL_SYS_BOOTSTAT_BC_RESETVAL (0x00000000u)
/*----BC Tokens----*/
#define CSL_SYS_BOOTSTAT_BC_BOOT_NOTCOMPLETE (0x00000000u)
#define CSL_SYS_BOOTSTAT_BC_BOOT_COMPLETE (0x00000001u)

#define CSL_SYS_BOOTSTAT_RESETVAL (0x00000000u)

/* BOOTCFG */

#define CSL_SYS_BOOTCFG_SEC_MASK (0x80000000u)
#define CSL_SYS_BOOTCFG_SEC_SHIFT (0x0000001Fu)
#define CSL_SYS_BOOTCFG_SEC_RESETVAL (0x00000000u)
/*----SEC Tokens----*/
#define CSL_SYS_BOOTCFG_SEC_NON_SECURE_DEV (0x00000000u)
#define CSL_SYS_BOOTCFG_SEC_SECURE_DEV (0x00000001u)


#define CSL_SYS_BOOTCFG_DSP_BT_MASK (0x00020000u)
#define CSL_SYS_BOOTCFG_DSP_BT_SHIFT (0x00000011u)
#define CSL_SYS_BOOTCFG_DSP_BT_RESETVAL (0x00000000u)
/*----DSP_BT Tokens----*/
#define CSL_SYS_BOOTCFG_DSP_BT_ARM_BOOT (0x00000000u)
#define CSL_SYS_BOOTCFG_DSP_BT_GEM_SELF_BOOT (0x00000001u)

#define CSL_SYS_BOOTCFG_PCIEN_MASK (0x00010000u)
#define CSL_SYS_BOOTCFG_PCIEN_SHIFT (0x00000010u)
#define CSL_SYS_BOOTCFG_PCIEN_RESETVAL (0x00000000u)
/*----PCIEN Tokens----*/
#define CSL_SYS_BOOTCFG_PCIEN_DISABLE (0x00000000u)
#define CSL_SYS_BOOTCFG_PCIEN_ENABLE (0x00000001u)


#define CSL_SYS_BOOTCFG_VADJEN_MASK (0x00001000u)
#define CSL_SYS_BOOTCFG_VADJEN_SHIFT (0x0000000Cu)
#define CSL_SYS_BOOTCFG_VADJEN_RESETVAL (0x00000000u)
/*----VADJEN Tokens----*/
#define CSL_SYS_BOOTCFG_VADJEN_DISABLE (0x00000000u)
#define CSL_SYS_BOOTCFG_VADJEN_ENABLE (0x00000001u)


#define CSL_SYS_BOOTCFG_CS2_BW_MASK (0x00000100u)
#define CSL_SYS_BOOTCFG_CS2_BW_SHIFT (0x00000008u)
#define CSL_SYS_BOOTCFG_CS2_BW_RESETVAL (0x00000000u)
/*----CS2_BW Tokens----*/
#define CSL_SYS_BOOTCFG_CS2_BW_8BIT (0x00000000u)
#define CSL_SYS_BOOTCFG_CS2_BW_16BIT (0x00000001u)


#define CSL_SYS_BOOTCFG_BOOTMODE_MASK (0x0000000Fu)
#define CSL_SYS_BOOTCFG_BOOTMODE_SHIFT (0x00000000u)
#define CSL_SYS_BOOTCFG_BOOTMODE_RESETVAL (0x00000000u)

#define CSL_SYS_BOOTCFG_RESETVAL (0x00000000u)

/* SMTREFLEX */


#define CSL_SYS_SMTREFLEX_SMTREFLEX_MASK (0x00000003u)
#define CSL_SYS_SMTREFLEX_SMTREFLEX_SHIFT (0x00000000u)
#define CSL_SYS_SMTREFLEX_SMTREFLEX_RESETVAL (0x00000000u)

#define CSL_SYS_SMTREFLEX_RESETVAL (0x00000000u)

/* DDR_SLEW */


#define CSL_SYS_DDR_SLEW_DDRDATA_SLEW_MASK (0x0000000Cu)
#define CSL_SYS_DDR_SLEW_DDRDATA_SLEW_SHIFT (0x00000002u)
#define CSL_SYS_DDR_SLEW_DDRDATA_SLEW_RESETVAL (0x00000000u)

#define CSL_SYS_DDR_SLEW_DDRCMD_SLEW_MASK (0x00000003u)
#define CSL_SYS_DDR_SLEW_DDRCMD_SLEW_SHIFT (0x00000000u)
#define CSL_SYS_DDR_SLEW_DDRCMD_SLEW_RESETVAL (0x00000000u)

#define CSL_SYS_DDR_SLEW_RESETVAL (0x00000000u)

/* ARMBOOT */


#define CSL_SYS_ARMBOOT_ADDRMOD_MASK (0x00000010u)
#define CSL_SYS_ARMBOOT_ADDRMOD_SHIFT (0x00000004u)
#define CSL_SYS_ARMBOOT_ADDRMOD_RESETVAL (0x00000000u)
/*----ADDRMOD Tokens----*/
#define CSL_SYS_ARMBOOT_ADDRMOD_DISABLE_MODIFY (0x00000000u)
#define CSL_SYS_ARMBOOT_ADDRMOD_ENABLE_MODIFY (0x00000001u)


#define CSL_SYS_ARMBOOT_TRAMBOOT_MASK (0x00000001u)
#define CSL_SYS_ARMBOOT_TRAMBOOT_SHIFT (0x00000000u)
#define CSL_SYS_ARMBOOT_TRAMBOOT_RESETVAL (0x00000000u)
/*----TRAMBOOT Tokens----*/
#define CSL_SYS_ARMBOOT_TRAMBOOT_USE_BTMODE (0x00000000u)
#define CSL_SYS_ARMBOOT_TRAMBOOT_RAM_BOOT (0x00000001u)

#define CSL_SYS_ARMBOOT_RESETVAL (0x00000000u)

/* DEVICE_ID */

#define CSL_SYS_DEVICE_ID_DEVREV_MASK (0xF0000000u)
#define CSL_SYS_DEVICE_ID_DEVREV_SHIFT (0x0000001Cu)
#define CSL_SYS_DEVICE_ID_DEVREV_RESETVAL (0x00000000u)

#define CSL_SYS_DEVICE_ID_PARTNUM_MASK (0x0FFFF000u)
#define CSL_SYS_DEVICE_ID_PARTNUM_SHIFT (0x0000000Cu)
#define CSL_SYS_DEVICE_ID_PARTNUM_RESETVAL (0x0000B770u)

#define CSL_SYS_DEVICE_ID_MFCR_MASK (0x00000FFEu)
#define CSL_SYS_DEVICE_ID_MFCR_SHIFT (0x00000001u)
#define CSL_SYS_DEVICE_ID_MFCR_RESETVAL (0x00000017u)


#define CSL_SYS_DEVICE_ID_RESETVAL (0x0B77002Fu)

/* IMCOPBOOT */


#define CSL_SYS_IMCOPBOOT_INITRAM1_MASK (0x00100000u)
#define CSL_SYS_IMCOPBOOT_INITRAM1_SHIFT (0x00000014u)
#define CSL_SYS_IMCOPBOOT_INITRAM1_RESETVAL (0x00000000u)
/*----INITRAM1 Tokens----*/
#define CSL_SYS_IMCOPBOOT_INITRAM1_TCM_DISABLE (0x00000000u)
#define CSL_SYS_IMCOPBOOT_INITRAM1_TCM_ENABLE (0x00000001u)


#define CSL_SYS_IMCOPBOOT_COP1HLT_MASK (0x00010000u)
#define CSL_SYS_IMCOPBOOT_COP1HLT_SHIFT (0x00000010u)
#define CSL_SYS_IMCOPBOOT_COP1HLT_RESETVAL (0x00000001u)
/*----COP1HLT Tokens----*/
#define CSL_SYS_IMCOPBOOT_COP1HLT_IAHB_FETCH_ENABLE (0x00000000u)
#define CSL_SYS_IMCOPBOOT_COP1HLT_IAHB_FETCH_STALLED (0x00000001u)


#define CSL_SYS_IMCOPBOOT_INITRAM0_MASK (0x00000010u)
#define CSL_SYS_IMCOPBOOT_INITRAM0_SHIFT (0x00000004u)
#define CSL_SYS_IMCOPBOOT_INITRAM0_RESETVAL (0x00000000u)
/*----INITRAM0 Tokens----*/
#define CSL_SYS_IMCOPBOOT_INITRAM0_TCM_DISABLE (0x00000000u)
#define CSL_SYS_IMCOPBOOT_INITRAM0_TCM_ENABLE (0x00000001u)


#define CSL_SYS_IMCOPBOOT_COP0HLT_MASK (0x00000001u)
#define CSL_SYS_IMCOPBOOT_COP0HLT_SHIFT (0x00000000u)
#define CSL_SYS_IMCOPBOOT_COP0HLT_RESETVAL (0x00000001u)
/*----COP0HLT Tokens----*/
#define CSL_SYS_IMCOPBOOT_COP0HLT_IAHB_FETCH_ENABLE (0x00000000u)
#define CSL_SYS_IMCOPBOOT_COP0HLT_IAHB_FETCH_STALLED (0x00000001u)

#define CSL_SYS_IMCOPBOOT_RESETVAL (0x00010001u)

/* UHPI_CTRL */


#define CSL_SYS_UHPI_CTRL_HRDYMODE_MASK (0x00030000u)
#define CSL_SYS_UHPI_CTRL_HRDYMODE_SHIFT (0x00000010u)
#define CSL_SYS_UHPI_CTRL_HRDYMODE_RESETVAL (0x00000000u)
/*----HRDYMODE Tokens----*/
#define CSL_SYS_UHPI_CTRL_HRDYMODE_HRDYN_ACTIVE_LOW (0x00000000u)
#define CSL_SYS_UHPI_CTRL_HRDYMODE_HRDY_ACTIVE_HIGH (0x00000001u)
#define CSL_SYS_UHPI_CTRL_HRDYMODE_INTERNAL_HRDYN (0x00000002u)
#define CSL_SYS_UHPI_CTRL_HRDYMODE_INTERNAL_HRDY (0x00000003u)

#define CSL_SYS_UHPI_CTRL_WIDTH_MASK (0x00008000u)
#define CSL_SYS_UHPI_CTRL_WIDTH_SHIFT (0x0000000Fu)
#define CSL_SYS_UHPI_CTRL_WIDTH_RESETVAL (0x00000000u)
/*----WIDTH Tokens----*/
#define CSL_SYS_UHPI_CTRL_WIDTH_16BIT (0x00000000u)
#define CSL_SYS_UHPI_CTRL_WIDTH_32BIT (0x00000001u)


#define CSL_SYS_UHPI_CTRL_CTLMODE_MASK (0x00000200u)
#define CSL_SYS_UHPI_CTRL_CTLMODE_SHIFT (0x00000009u)
#define CSL_SYS_UHPI_CTRL_CTLMODE_RESETVAL (0x00000000u)
/*----CTLMODE Tokens----*/
#define CSL_SYS_UHPI_CTRL_CTLMODE_HOST (0x00000000u)
#define CSL_SYS_UHPI_CTRL_CTLMODE_DAVINCIHD (0x00000001u)

#define CSL_SYS_UHPI_CTRL_ADDMODE_MASK (0x00000100u)
#define CSL_SYS_UHPI_CTRL_ADDMODE_SHIFT (0x00000008u)
#define CSL_SYS_UHPI_CTRL_ADDMODE_RESETVAL (0x00000000u)
/*----ADDMODE Tokens----*/
#define CSL_SYS_UHPI_CTRL_ADDMODE_HOST (0x00000000u)
#define CSL_SYS_UHPI_CTRL_ADDMODE_DAVINCIHD (0x00000001u)

#define CSL_SYS_UHPI_CTRL_TIMOUT_MASK (0x000000FFu)
#define CSL_SYS_UHPI_CTRL_TIMOUT_SHIFT (0x00000000u)
#define CSL_SYS_UHPI_CTRL_TIMOUT_RESETVAL (0x00000080u)

#define CSL_SYS_UHPI_CTRL_RESETVAL (0x00000080u)

/* USB_PHY_CTRL */


#define CSL_SYS_USB_PHY_CTRL_DATAPOL_MASK (0x00040000u)
#define CSL_SYS_USB_PHY_CTRL_DATAPOL_SHIFT (0x00000012u)
#define CSL_SYS_USB_PHY_CTRL_DATAPOL_RESETVAL (0x00000001u)
/*----DATAPOL Tokens----*/
#define CSL_SYS_USB_PHY_CTRL_DATAPOL_INVERTED (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_DATAPOL_NORMAL (0x00000001u)

#define CSL_SYS_USB_PHY_CTRL_VBUSVAL_MASK (0x00020000u)
#define CSL_SYS_USB_PHY_CTRL_VBUSVAL_SHIFT (0x00000011u)
#define CSL_SYS_USB_PHY_CTRL_VBUSVAL_RESETVAL (0x00000000u)
/*----VBUSVAL Tokens----*/
#define CSL_SYS_USB_PHY_CTRL_VBUSVAL_DISABLE (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_VBUSVAL_SESSION_START (0x00000001u)

#define CSL_SYS_USB_PHY_CTRL_USBID_MASK (0x00010000u)
#define CSL_SYS_USB_PHY_CTRL_USBID_SHIFT (0x00000010u)
#define CSL_SYS_USB_PHY_CTRL_USBID_RESETVAL (0x00000000u)
/*----USBID Tokens----*/
#define CSL_SYS_USB_PHY_CTRL_USBID_HOST (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_USBID_PERIPHERAL (0x00000001u)


#define CSL_SYS_USB_PHY_CTRL_PHYCLKGD_MASK (0x00000100u)
#define CSL_SYS_USB_PHY_CTRL_PHYCLKGD_SHIFT (0x00000008u)
#define CSL_SYS_USB_PHY_CTRL_PHYCLKGD_RESETVAL (0x00000000u)
/*----PHYCLKGD Tokens----*/
#define CSL_SYS_USB_PHY_CTRL_PHYCLKGD_NOT_GOOD (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_PHYCLKGD_GOOD (0x00000001u)


#define CSL_SYS_USB_PHY_CTRL_PHYPLLON_MASK (0x00000010u)
#define CSL_SYS_USB_PHY_CTRL_PHYPLLON_SHIFT (0x00000004u)
#define CSL_SYS_USB_PHY_CTRL_PHYPLLON_RESETVAL (0x00000000u)
/*----PHYPLLON Tokens----*/
#define CSL_SYS_USB_PHY_CTRL_PHYPLLON_NORMAL_OPER (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_PHYPLLON_OVERRIDE_SUSP_STATE (0x00000001u)


#define CSL_SYS_USB_PHY_CTRL_PHYPDWN_MASK (0x00000001u)
#define CSL_SYS_USB_PHY_CTRL_PHYPDWN_SHIFT (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_PHYPDWN_RESETVAL (0x00000001u)
/*----PHYPDWN Tokens----*/
#define CSL_SYS_USB_PHY_CTRL_PHYPDWN_PWRED (0x00000000u)
#define CSL_SYS_USB_PHY_CTRL_PHYPDWN_PWROFF (0x00000001u)

#define CSL_SYS_USB_PHY_CTRL_RESETVAL (0x00040001u)

/* VIDCLKCTL */


#define CSL_SYS_VIDCLKCTL_VCH3CLK_MASK (0x00007000u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_SHIFT (0x0000000Cu)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_RESETVAL (0x00000007u)
/*----VCH3CLK Tokens----*/
#define CSL_SYS_VIDCLKCTL_VCH3CLK_CRG0_VCXI (0x00000000u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_CRG1_VCXI (0x00000001u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_SYSCLK8 (0x00000002u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_AUXCLK (0x00000003u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_V27_PLLIN (0x00000005u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_VPIF_CLKIN2 (0x00000006u)
#define CSL_SYS_VIDCLKCTL_VCH3CLK_VPIF_CLKIN3 (0x00000007u)


#define CSL_SYS_VIDCLKCTL_VCH2CLK_MASK (0x00000700u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_SHIFT (0x00000008u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_RESETVAL (0x00000006u)
/*----VCH2CLK Tokens----*/
#define CSL_SYS_VIDCLKCTL_VCH2CLK_CRG0_VCXI (0x00000000u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_CRG1_VCXI (0x00000001u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_SYSCLK8 (0x00000002u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_AUXCLK (0x00000003u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_V27_PLLIN (0x00000005u)
#define CSL_SYS_VIDCLKCTL_VCH2CLK_VPIF_CLKIN2 (0x00000006u)


#define CSL_SYS_VIDCLKCTL_VCH1CLK_MASK (0x00000010u)
#define CSL_SYS_VIDCLKCTL_VCH1CLK_SHIFT (0x00000004u)
#define CSL_SYS_VIDCLKCTL_VCH1CLK_RESETVAL (0x00000001u)
/*----VCH1CLK Tokens----*/
#define CSL_SYS_VIDCLKCTL_VCH1CLK_VPIF_CLKIN0 (0x00000000u)
#define CSL_SYS_VIDCLKCTL_VCH1CLK_VPIF_CLKIN1 (0x00000001u)


#define CSL_SYS_VIDCLKCTL_RESETVAL (0x00007610u)

/* MSTPRI0 */


#define CSL_SYS_MSTPRI0_IMCOP1P_MASK (0x00700000u)
#define CSL_SYS_MSTPRI0_IMCOP1P_SHIFT (0x00000014u)
#define CSL_SYS_MSTPRI0_IMCOP1P_RESETVAL (0x00000003u)


#define CSL_SYS_MSTPRI0_IMCOP0P_MASK (0x00070000u)
#define CSL_SYS_MSTPRI0_IMCOP0P_SHIFT (0x00000010u)
#define CSL_SYS_MSTPRI0_IMCOP0P_RESETVAL (0x00000003u)


#define CSL_SYS_MSTPRI0_GEMDMAP_MASK (0x00007000u)
#define CSL_SYS_MSTPRI0_GEMDMAP_SHIFT (0x0000000Cu)
#define CSL_SYS_MSTPRI0_GEMDMAP_RESETVAL (0x00000004u)


#define CSL_SYS_MSTPRI0_GEMCFGP_MASK (0x00000700u)
#define CSL_SYS_MSTPRI0_GEMCFGP_SHIFT (0x00000008u)
#define CSL_SYS_MSTPRI0_GEMCFGP_RESETVAL (0x00000004u)


#define CSL_SYS_MSTPRI0_ARMDATAP_MASK (0x00000070u)
#define CSL_SYS_MSTPRI0_ARMDATAP_SHIFT (0x00000004u)
#define CSL_SYS_MSTPRI0_ARMDATAP_RESETVAL (0x00000004u)


#define CSL_SYS_MSTPRI0_ARMINSTP_MASK (0x00000007u)
#define CSL_SYS_MSTPRI0_ARMINSTP_SHIFT (0x00000000u)
#define CSL_SYS_MSTPRI0_ARMINSTP_RESETVAL (0x00000004u)

#define CSL_SYS_MSTPRI0_RESETVAL (0x00334444u)

/* MSTPRI1 */


#define CSL_SYS_MSTPRI1_GRENGP_MASK (0x70000000u)
#define CSL_SYS_MSTPRI1_GRENGP_SHIFT (0x0000001Cu)
#define CSL_SYS_MSTPRI1_GRENGP_RESETVAL (0x00000004u)


#define CSL_SYS_MSTPRI1_PCIP_MASK (0x07000000u)
#define CSL_SYS_MSTPRI1_PCIP_SHIFT (0x00000018u)
#define CSL_SYS_MSTPRI1_PCIP_RESETVAL (0x00000006u)


#define CSL_SYS_MSTPRI1_HPIP_MASK (0x00700000u)
#define CSL_SYS_MSTPRI1_HPIP_SHIFT (0x00000014u)
#define CSL_SYS_MSTPRI1_HPIP_RESETVAL (0x00000006u)


#define CSL_SYS_MSTPRI1_VLYNQP_MASK (0x00070000u)
#define CSL_SYS_MSTPRI1_VLYNQP_SHIFT (0x00000010u)
#define CSL_SYS_MSTPRI1_VLYNQP_RESETVAL (0x00000005u)


#define CSL_SYS_MSTPRI1_ATAP_MASK (0x00007000u)
#define CSL_SYS_MSTPRI1_ATAP_SHIFT (0x0000000Cu)
#define CSL_SYS_MSTPRI1_ATAP_RESETVAL (0x00000005u)


#define CSL_SYS_MSTPRI1_USBP_MASK (0x00000700u)
#define CSL_SYS_MSTPRI1_USBP_SHIFT (0x00000008u)
#define CSL_SYS_MSTPRI1_USBP_RESETVAL (0x00000005u)


#define CSL_SYS_MSTPRI1_CPGMACP_MASK (0x00000007u)
#define CSL_SYS_MSTPRI1_CPGMACP_SHIFT (0x00000000u)
#define CSL_SYS_MSTPRI1_CPGMACP_RESETVAL (0x00000005u)

#define CSL_SYS_MSTPRI1_RESETVAL (0x46655505u)

/* MSTPRI2 */


#define CSL_SYS_MSTPRI2_SPIO1P_MASK (0x70000000u)
#define CSL_SYS_MSTPRI2_SPIO1P_SHIFT (0x0000001Cu)
#define CSL_SYS_MSTPRI2_SPIO1P_RESETVAL (0x00000001u)


#define CSL_SYS_MSTPRI2_SPIO0P_MASK (0x07000000u)
#define CSL_SYS_MSTPRI2_SPIO0P_SHIFT (0x00000018u)
#define CSL_SYS_MSTPRI2_SPIO0P_RESETVAL (0x00000001u)


#define CSL_SYS_MSTPRI2_VP1P_MASK (0x00700000u)
#define CSL_SYS_MSTPRI2_VP1P_SHIFT (0x00000014u)
#define CSL_SYS_MSTPRI2_VP1P_RESETVAL (0x00000001u)


#define CSL_SYS_MSTPRI2_VP0P_MASK (0x00070000u)
#define CSL_SYS_MSTPRI2_VP0P_SHIFT (0x00000010u)
#define CSL_SYS_MSTPRI2_VP0P_RESETVAL (0x00000001u)


#define CSL_SYS_MSTPRI2_TPTC3P_MASK (0x00007000u)
#define CSL_SYS_MSTPRI2_TPTC3P_SHIFT (0x0000000Cu)
#define CSL_SYS_MSTPRI2_TPTC3P_RESETVAL (0x00000002u)


#define CSL_SYS_MSTPRI2_TPTC2P_MASK (0x00000700u)
#define CSL_SYS_MSTPRI2_TPTC2P_SHIFT (0x00000008u)
#define CSL_SYS_MSTPRI2_TPTC2P_RESETVAL (0x00000002u)


#define CSL_SYS_MSTPRI2_TPTC1P_MASK (0x00000070u)
#define CSL_SYS_MSTPRI2_TPTC1P_SHIFT (0x00000004u)
#define CSL_SYS_MSTPRI2_TPTC1P_RESETVAL (0x00000002u)


#define CSL_SYS_MSTPRI2_TPTC0P_MASK (0x00000007u)
#define CSL_SYS_MSTPRI2_TPTC0P_SHIFT (0x00000000u)
#define CSL_SYS_MSTPRI2_TPTC0P_RESETVAL (0x00000002u)

#define CSL_SYS_MSTPRI2_RESETVAL (0x11112222u)

/* VDD3P3VPWDN */


#define CSL_SYS_VDD3P3VPWDN_USBV_MASK (0x10000000u)
#define CSL_SYS_VDD3P3VPWDN_USBV_SHIFT (0x0000001Cu)
#define CSL_SYS_VDD3P3VPWDN_USBV_RESETVAL (0x00000001u)
/*----USBV Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_USBV_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_USBV_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_CLKOUT_MASK (0x08000000u)
#define CSL_SYS_VDD3P3VPWDN_CLKOUT_SHIFT (0x0000001Bu)
#define CSL_SYS_VDD3P3VPWDN_CLKOUT_RESETVAL (0x00000000u)
/*----CLKOUT Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_CLKOUT_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_CLKOUT_PWDOWN (0x00000001u)


#define CSL_SYS_VDD3P3VPWDN_SPI_MASK (0x02000000u)
#define CSL_SYS_VDD3P3VPWDN_SPI_SHIFT (0x00000019u)
#define CSL_SYS_VDD3P3VPWDN_SPI_RESETVAL (0x00000001u)
/*----SPI Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_SPI_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_SPI_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_VLYNQ_MASK (0x01000000u)
#define CSL_SYS_VDD3P3VPWDN_VLYNQ_SHIFT (0x00000018u)
#define CSL_SYS_VDD3P3VPWDN_VLYNQ_RESETVAL (0x00000001u)
/*----VLYNQ Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_VLYNQ_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_VLYNQ_PWDOWN (0x00000001u)


#define CSL_SYS_VDD3P3VPWDN_GMII_MASK (0x00200000u)
#define CSL_SYS_VDD3P3VPWDN_GMII_SHIFT (0x00000015u)
#define CSL_SYS_VDD3P3VPWDN_GMII_RESETVAL (0x00000001u)
/*----GMII Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_GMII_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_GMII_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_MII_MASK (0x00100000u)
#define CSL_SYS_VDD3P3VPWDN_MII_SHIFT (0x00000014u)
#define CSL_SYS_VDD3P3VPWDN_MII_RESETVAL (0x00000001u)
/*----MII Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_MII_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_MII_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_MCASP1_MASK (0x00080000u)
#define CSL_SYS_VDD3P3VPWDN_MCASP1_SHIFT (0x00000013u)
#define CSL_SYS_VDD3P3VPWDN_MCASP1_RESETVAL (0x00000001u)
/*----MCASP1 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_MCASP1_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_MCASP1_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_MCASP0_MASK (0x00040000u)
#define CSL_SYS_VDD3P3VPWDN_MCASP0_SHIFT (0x00000012u)
#define CSL_SYS_VDD3P3VPWDN_MCASP0_RESETVAL (0x00000001u)
/*----MCASP0 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_MCASP0_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_MCASP0_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_PCIHPI1_MASK (0x00020000u)
#define CSL_SYS_VDD3P3VPWDN_PCIHPI1_SHIFT (0x00000011u)
#define CSL_SYS_VDD3P3VPWDN_PCIHPI1_RESETVAL (0x00000000u)
/*----PCIHPI1 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_PCIHPI1_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_PCIHPI1_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_PCIHPI0_MASK (0x00010000u)
#define CSL_SYS_VDD3P3VPWDN_PCIHPI0_SHIFT (0x00000010u)
#define CSL_SYS_VDD3P3VPWDN_PCIHPI0_RESETVAL (0x00000000u)
/*----PCIHPI0 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_PCIHPI0_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_PCIHPI0_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_GPIO_MASK (0x00008000u)
#define CSL_SYS_VDD3P3VPWDN_GPIO_SHIFT (0x0000000Fu)
#define CSL_SYS_VDD3P3VPWDN_GPIO_RESETVAL (0x00000000u)
/*----GPIO Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_GPIO_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_GPIO_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_WDTIM_MASK (0x00004000u)
#define CSL_SYS_VDD3P3VPWDN_WDTIM_SHIFT (0x0000000Eu)
#define CSL_SYS_VDD3P3VPWDN_WDTIM_RESETVAL (0x00000000u)
/*----WDTIM Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_WDTIM_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_WDTIM_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_TIM23_MASK (0x00002000u)
#define CSL_SYS_VDD3P3VPWDN_TIM23_SHIFT (0x0000000Du)
#define CSL_SYS_VDD3P3VPWDN_TIM23_RESETVAL (0x00000001u)
/*----TIM23 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_TIM23_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_TIM23_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_TIM01_MASK (0x00001000u)
#define CSL_SYS_VDD3P3VPWDN_TIM01_SHIFT (0x0000000Cu)
#define CSL_SYS_VDD3P3VPWDN_TIM01_RESETVAL (0x00000001u)
/*----TIM01 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_TIM01_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_TIM01_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_PWM1_MASK (0x00000800u)
#define CSL_SYS_VDD3P3VPWDN_PWM1_SHIFT (0x0000000Bu)
#define CSL_SYS_VDD3P3VPWDN_PWM1_RESETVAL (0x00000001u)
/*----PWM1 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_PWM1_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_PWM1_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_PWM0_MASK (0x00000400u)
#define CSL_SYS_VDD3P3VPWDN_PWM0_SHIFT (0x0000000Au)
#define CSL_SYS_VDD3P3VPWDN_PWM0_RESETVAL (0x00000001u)
/*----PWM0 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_PWM0_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_PWM0_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_UR2FC_MASK (0x00000200u)
#define CSL_SYS_VDD3P3VPWDN_UR2FC_SHIFT (0x00000009u)
#define CSL_SYS_VDD3P3VPWDN_UR2FC_RESETVAL (0x00000001u)
/*----UR2FC Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_UR2FC_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_UR2FC_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_UR2DAT_MASK (0x00000100u)
#define CSL_SYS_VDD3P3VPWDN_UR2DAT_SHIFT (0x00000008u)
#define CSL_SYS_VDD3P3VPWDN_UR2DAT_RESETVAL (0x00000001u)
/*----UR2DAT Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_UR2DAT_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_UR2DAT_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_UR1FC_MASK (0x00000080u)
#define CSL_SYS_VDD3P3VPWDN_UR1FC_SHIFT (0x00000007u)
#define CSL_SYS_VDD3P3VPWDN_UR1FC_RESETVAL (0x00000001u)
/*----UR1FC Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_UR1FC_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_UR1FC_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_UR1DAT_MASK (0x00000040u)
#define CSL_SYS_VDD3P3VPWDN_UR1DAT_SHIFT (0x00000006u)
#define CSL_SYS_VDD3P3VPWDN_UR1DAT_RESETVAL (0x00000001u)
/*----UR1DAT Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_UR1DAT_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_UR1DAT_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_UR0MDM_MASK (0x00000020u)
#define CSL_SYS_VDD3P3VPWDN_UR0MDM_SHIFT (0x00000005u)
#define CSL_SYS_VDD3P3VPWDN_UR0MDM_RESETVAL (0x00000001u)
/*----UR0MDM Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_UR0MDM_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_UR0MDM_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_UR0DF_MASK (0x00000010u)
#define CSL_SYS_VDD3P3VPWDN_UR0DF_SHIFT (0x00000004u)
#define CSL_SYS_VDD3P3VPWDN_UR0DF_RESETVAL (0x00000001u)
/*----UR0DF Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_UR0DF_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_UR0DF_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_VPIF3_MASK (0x00000008u)
#define CSL_SYS_VDD3P3VPWDN_VPIF3_SHIFT (0x00000003u)
#define CSL_SYS_VDD3P3VPWDN_VPIF3_RESETVAL (0x00000001u)
/*----VPIF3 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_VPIF3_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_VPIF3_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_VPIF2_MASK (0x00000004u)
#define CSL_SYS_VDD3P3VPWDN_VPIF2_SHIFT (0x00000002u)
#define CSL_SYS_VDD3P3VPWDN_VPIF2_RESETVAL (0x00000001u)
/*----VPIF2 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_VPIF2_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_VPIF2_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_VPIF1_MASK (0x00000002u)
#define CSL_SYS_VDD3P3VPWDN_VPIF1_SHIFT (0x00000001u)
#define CSL_SYS_VDD3P3VPWDN_VPIF1_RESETVAL (0x00000001u)
/*----VPIF1 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_VPIF1_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_VPIF1_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_VPIF0_MASK (0x00000001u)
#define CSL_SYS_VDD3P3VPWDN_VPIF0_SHIFT (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_VPIF0_RESETVAL (0x00000001u)
/*----VPIF0 Tokens----*/
#define CSL_SYS_VDD3P3VPWDN_VPIF0_PWUP (0x00000000u)
#define CSL_SYS_VDD3P3VPWDN_VPIF0_PWDOWN (0x00000001u)

#define CSL_SYS_VDD3P3VPWDN_RESETVAL (0x133C3FFFu)

/* DFTENABLE */


#define CSL_SYS_DFTENABLE_DFT_EN_MASK (0x00000001u)
#define CSL_SYS_DFTENABLE_DFT_EN_SHIFT (0x00000000u)
#define CSL_SYS_DFTENABLE_DFT_EN_RESETVAL (0x00000000u)
/*----DFT_EN Tokens----*/
#define CSL_SYS_DFTENABLE_DFT_EN_DISABLE (0x00000000u)
#define CSL_SYS_DFTENABLE_DFT_EN_ENABLE (0x00000001u)

#define CSL_SYS_DFTENABLE_RESETVAL (0x00000000u)

/* SPIOCTL */


#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_MASK (0x00007000u)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_SHIFT (0x0000000Cu)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_RESETVAL (0x00000000u)
/*----SPIO1_CNTCLK Tokens----*/
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_CRG1_VCXI (0x00000000u)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_STCSRC_CLKIN (0x00000001u)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_AUXCLK (0x00000002u)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_CRG0_VCXI (0x00000003u)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_VPIF_CLKIN2 (0x00000004u)
#define CSL_SYS_SPIOCTL_SPIO1_CNTCLK_VPIF_CLKIN3 (0x00000005u)

#define CSL_SYS_SPIOCTL_STSO_CLK_MASK (0x00000F00u)
#define CSL_SYS_SPIOCTL_STSO_CLK_SHIFT (0x00000008u)
#define CSL_SYS_SPIOCTL_STSO_CLK_RESETVAL (0x00000000u)
/*----STSO_CLK Tokens----*/
#define CSL_SYS_SPIOCTL_STSO_CLK_CRG1_VCXI (0x00000000u)
#define CSL_SYS_SPIOCTL_STSO_CLK_STCSRC_CLKIN (0x00000001u)
#define CSL_SYS_SPIOCTL_STSO_CLK_SYSCLK6 (0x00000002u)
#define CSL_SYS_SPIOCTL_STSO_CLK_SYSCLKBP (0x00000003u)
#define CSL_SYS_SPIOCTL_STSO_CLK_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_SPIOCTL_STSO_CLK_STSI_CLK (0x00000005u)
#define CSL_SYS_SPIOCTL_STSO_CLK_VPIF_CLKIN2 (0x00000006u)
#define CSL_SYS_SPIOCTL_STSO_CLK_CRG0_VCXI (0x00000008u)


#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_MASK (0x00000070u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_SHIFT (0x00000004u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_RESETVAL (0x00000000u)
/*----SPIO0_CNTCLK Tokens----*/
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_CRG0_VCXI (0x00000000u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_STCSRC_CLKIN (0x00000001u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_AUXCLK (0x00000002u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_CRG1_VCXI (0x00000003u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_SPIOCTL_SPIO0_CNTCLK_VPIF_CLKIN1 (0x00000005u)


#define CSL_SYS_SPIOCTL_PTSO_CLK_MASK (0x00000007u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_SHIFT (0x00000000u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_RESETVAL (0x00000000u)
/*----PTSO_CLK Tokens----*/
#define CSL_SYS_SPIOCTL_PTSO_CLK_CRG0_VCXI (0x00000000u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_STCSRC_CLKIN (0x00000001u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_SYSCLK5 (0x00000002u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_SYSCLKBP (0x00000003u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_VPIF_CLKIN1 (0x00000005u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_PTSI_CLK (0x00000006u)
#define CSL_SYS_SPIOCTL_PTSO_CLK_CRG1_VCXI (0x00000007u)

#define CSL_SYS_SPIOCTL_RESETVAL (0x00000000u)

/* PWMCTL */


#define CSL_SYS_PWMCTL_PWM1TRG_MASK (0x000000F0u)
#define CSL_SYS_PWMCTL_PWM1TRG_SHIFT (0x00000004u)
#define CSL_SYS_PWMCTL_PWM1TRG_RESETVAL (0x0000000Fu)
/*----PWM1TRG Tokens----*/
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO0 (0x00000000u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO1 (0x00000001u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO2 (0x00000002u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO3 (0x00000003u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO4 (0x00000004u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO5 (0x00000005u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO6 (0x00000006u)
#define CSL_SYS_PWMCTL_PWM1TRG_GPIO7 (0x00000007u)
#define CSL_SYS_PWMCTL_PWM1TRG_VPIF_VERT_INT0 (0x00000008u)
#define CSL_SYS_PWMCTL_PWM1TRG_VPIF_VERT_INT1 (0x00000009u)
#define CSL_SYS_PWMCTL_PWM1TRG_VPIF_VERT_INT2 (0x0000000Au)
#define CSL_SYS_PWMCTL_PWM1TRG_VPIF_VERT_INT3 (0x0000000Bu)
#define CSL_SYS_PWMCTL_PWM1TRG_DISABLED (0x0000000Cu)

#define CSL_SYS_PWMCTL_PWM0TRG_MASK (0x0000000Fu)
#define CSL_SYS_PWMCTL_PWM0TRG_SHIFT (0x00000000u)
#define CSL_SYS_PWMCTL_PWM0TRG_RESETVAL (0x0000000Fu)
/*----PWM0TRG Tokens----*/
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO0 (0x00000000u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO1 (0x00000001u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO2 (0x00000002u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO3 (0x00000003u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO4 (0x00000004u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO5 (0x00000005u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO6 (0x00000006u)
#define CSL_SYS_PWMCTL_PWM0TRG_GPIO7 (0x00000007u)
#define CSL_SYS_PWMCTL_PWM0TRG_VPIF_VERT_INT0 (0x00000008u)
#define CSL_SYS_PWMCTL_PWM0TRG_VPIF_VERT_INT1 (0x00000009u)
#define CSL_SYS_PWMCTL_PWM0TRG_VPIF_VERT_INT2 (0x0000000Au)
#define CSL_SYS_PWMCTL_PWM0TRG_VPIF_VERT_INT3 (0x0000000Bu)
#define CSL_SYS_PWMCTL_PWM0TRG_DISABLED (0x0000000Cu)

#define CSL_SYS_PWMCTL_RESETVAL (0x000000FFu)

/* TPTCCFG */


#define CSL_SYS_TPTCCFG_TC3DBS_MASK (0x000000C0u)
#define CSL_SYS_TPTCCFG_TC3DBS_SHIFT (0x00000006u)
#define CSL_SYS_TPTCCFG_TC3DBS_RESETVAL (0x00000001u)
/*----TC3DBS Tokens----*/
#define CSL_SYS_TPTCCFG_TC3DBS_16BYTE (0x00000000u)
#define CSL_SYS_TPTCCFG_TC3DBS_32BYTE (0x00000001u)
#define CSL_SYS_TPTCCFG_TC3DBS_64BYTE (0x00000002u)

#define CSL_SYS_TPTCCFG_TC2DBS_MASK (0x00000030u)
#define CSL_SYS_TPTCCFG_TC2DBS_SHIFT (0x00000004u)
#define CSL_SYS_TPTCCFG_TC2DBS_RESETVAL (0x00000001u)
/*----TC2DBS Tokens----*/
#define CSL_SYS_TPTCCFG_TC2DBS_16BYTE (0x00000000u)
#define CSL_SYS_TPTCCFG_TC2DBS_32BYTE (0x00000001u)
#define CSL_SYS_TPTCCFG_TC2DBS_64BYTE (0x00000002u)

#define CSL_SYS_TPTCCFG_TC1DBS_MASK (0x0000000Cu)
#define CSL_SYS_TPTCCFG_TC1DBS_SHIFT (0x00000002u)
#define CSL_SYS_TPTCCFG_TC1DBS_RESETVAL (0x00000001u)
/*----TC1DBS Tokens----*/
#define CSL_SYS_TPTCCFG_TC1DBS_16BYTE (0x00000000u)
#define CSL_SYS_TPTCCFG_TC1DBS_32BYTE (0x00000001u)
#define CSL_SYS_TPTCCFG_TC1DBS_64BYTE (0x00000002u)

#define CSL_SYS_TPTCCFG_TC0DBS_MASK (0x00000003u)
#define CSL_SYS_TPTCCFG_TC0DBS_SHIFT (0x00000000u)
#define CSL_SYS_TPTCCFG_TC0DBS_RESETVAL (0x00000001u)
/*----TC0DBS Tokens----*/
#define CSL_SYS_TPTCCFG_TC0DBS_16BYTE (0x00000000u)
#define CSL_SYS_TPTCCFG_TC0DBS_32BYTE (0x00000001u)
#define CSL_SYS_TPTCCFG_TC0DBS_64BYTE (0x00000002u)

#define CSL_SYS_TPTCCFG_RESETVAL (0x00000055u)

/* CLKCTL */


#define CSL_SYS_CLKCTL_OSCPWRDN_MASK (0x02000000u)
#define CSL_SYS_CLKCTL_OSCPWRDN_SHIFT (0x00000019u)
#define CSL_SYS_CLKCTL_OSCPWRDN_RESETVAL (0x00000000u)
/*----OSCPWRDN Tokens----*/
#define CSL_SYS_CLKCTL_OSCPWRDN_BIAS_REG_CONNECTED (0x00000000u)
#define CSL_SYS_CLKCTL_OSCPWRDN_BIAS_REG_DISCONNECTED (0x00000001u)

#define CSL_SYS_CLKCTL_OSCDIS_MASK (0x01000000u)
#define CSL_SYS_CLKCTL_OSCDIS_SHIFT (0x00000018u)
#define CSL_SYS_CLKCTL_OSCDIS_RESETVAL (0x00000001u)
/*----OSCDIS Tokens----*/
#define CSL_SYS_CLKCTL_OSCDIS_AUX_OSC_ENABLE (0x00000000u)
#define CSL_SYS_CLKCTL_OSCDIS_AUX_OSC_DISABLE (0x00000001u)


#define CSL_SYS_CLKCTL_CLKOUT_MASK (0x000F0000u)
#define CSL_SYS_CLKCTL_CLKOUT_SHIFT (0x00000010u)
#define CSL_SYS_CLKCTL_CLKOUT_RESETVAL (0x00000008u)
/*----CLKOUT Tokens----*/
#define CSL_SYS_CLKCTL_CLKOUT_DISABLED (0x00000000u)
#define CSL_SYS_CLKCTL_CLKOUT_AUXCLK (0x00000001u)
#define CSL_SYS_CLKCTL_CLKOUT_OBSCLK (0x00000002u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK3 (0x00000003u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK4 (0x00000004u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK5 (0x00000005u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK6 (0x00000006u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK7 (0x00000007u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK8 (0x00000008u)
#define CSL_SYS_CLKCTL_CLKOUT_SYSCLK9 (0x00000009u)
#define CSL_SYS_CLKCTL_CLKOUT_X1_AUX (0x0000000Au)


#define CSL_SYS_CLKCTL_AUD_CLK1_MASK (0x00000F00u)
#define CSL_SYS_CLKCTL_AUD_CLK1_SHIFT (0x00000008u)
#define CSL_SYS_CLKCTL_AUD_CLK1_RESETVAL (0x00000000u)
/*----AUD_CLK1 Tokens----*/
#define CSL_SYS_CLKCTL_AUD_CLK1_DISABLED (0x00000000u)
#define CSL_SYS_CLKCTL_AUD_CLK1_AUXCLK (0x00000001u)
#define CSL_SYS_CLKCTL_AUD_CLK1_CRG0_VCXI (0x00000002u)
#define CSL_SYS_CLKCTL_AUD_CLK1_CRG1_VCXI (0x00000003u)
#define CSL_SYS_CLKCTL_AUD_CLK1_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_CLKCTL_AUD_CLK1_VPIF_CLKIN1 (0x00000005u)
#define CSL_SYS_CLKCTL_AUD_CLK1_VPIF_CLKIN2 (0x00000006u)
#define CSL_SYS_CLKCTL_AUD_CLK1_VPIF_CLKIN3 (0x00000007u)
#define CSL_SYS_CLKCTL_AUD_CLK1_X1_AUX (0x00000008u)
#define CSL_SYS_CLKCTL_AUD_CLK1_V27_PLLIN (0x00000009u)


#define CSL_SYS_CLKCTL_AUD_CLK0_MASK (0x0000000Fu)
#define CSL_SYS_CLKCTL_AUD_CLK0_SHIFT (0x00000000u)
#define CSL_SYS_CLKCTL_AUD_CLK0_RESETVAL (0x00000000u)
/*----AUD_CLK0 Tokens----*/
#define CSL_SYS_CLKCTL_AUD_CLK0_DISABLED (0x00000000u)
#define CSL_SYS_CLKCTL_AUD_CLK0_AUXCLK (0x00000001u)
#define CSL_SYS_CLKCTL_AUD_CLK0_CRG0_VCXI (0x00000002u)
#define CSL_SYS_CLKCTL_AUD_CLK0_CRG1_VCXI (0x00000003u)
#define CSL_SYS_CLKCTL_AUD_CLK0_VPIF_CLKIN0 (0x00000004u)
#define CSL_SYS_CLKCTL_AUD_CLK0_VPIF_CLKIN1 (0x00000005u)
#define CSL_SYS_CLKCTL_AUD_CLK0_VPIF_CLKIN2 (0x00000006u)
#define CSL_SYS_CLKCTL_AUD_CLK0_VPIF_CLKIN3 (0x00000007u)
#define CSL_SYS_CLKCTL_AUD_CLK0_X1_AUX (0x00000008u)
#define CSL_SYS_CLKCTL_AUD_CLK0_V27_PLLIN (0x00000009u)

#define CSL_SYS_CLKCTL_RESETVAL (0x01080000u)

/* DSPINT */


#define CSL_SYS_DSPINT_INTNMI_MASK (0x00000100u)
#define CSL_SYS_DSPINT_INTNMI_SHIFT (0x00000008u)
#define CSL_SYS_DSPINT_INTNMI_RESETVAL (0x00000000u)
/*----INTNMI Tokens----*/
#define CSL_SYS_DSPINT_INTNMI_NOINT (0x00000000u)
#define CSL_SYS_DSPINT_INTNMI_ACTIVEINT (0x00000001u)


#define CSL_SYS_DSPINT_INTDSP3_MASK (0x00000008u)
#define CSL_SYS_DSPINT_INTDSP3_SHIFT (0x00000003u)
#define CSL_SYS_DSPINT_INTDSP3_RESETVAL (0x00000000u)
/*----INTDSP3 Tokens----*/
#define CSL_SYS_DSPINT_INTDSP3_NOINT (0x00000000u)
#define CSL_SYS_DSPINT_INTDSP3_ACTIVEINT (0x00000001u)

#define CSL_SYS_DSPINT_INTDSP2_MASK (0x00000004u)
#define CSL_SYS_DSPINT_INTDSP2_SHIFT (0x00000002u)
#define CSL_SYS_DSPINT_INTDSP2_RESETVAL (0x00000000u)
/*----INTDSP2 Tokens----*/
#define CSL_SYS_DSPINT_INTDSP2_NOINT (0x00000000u)
#define CSL_SYS_DSPINT_INTDSP2_ACTIVEINT (0x00000001u)

#define CSL_SYS_DSPINT_INTDSP1_MASK (0x00000002u)
#define CSL_SYS_DSPINT_INTDSP1_SHIFT (0x00000001u)
#define CSL_SYS_DSPINT_INTDSP1_RESETVAL (0x00000000u)
/*----INTDSP1 Tokens----*/
#define CSL_SYS_DSPINT_INTDSP1_NOINT (0x00000000u)
#define CSL_SYS_DSPINT_INTDSP1_ACTIVEINT (0x00000001u)

#define CSL_SYS_DSPINT_INTDSP0_MASK (0x00000001u)
#define CSL_SYS_DSPINT_INTDSP0_SHIFT (0x00000000u)
#define CSL_SYS_DSPINT_INTDSP0_RESETVAL (0x00000000u)
/*----INTDSP0 Tokens----*/
#define CSL_SYS_DSPINT_INTDSP0_NOINT (0x00000000u)
#define CSL_SYS_DSPINT_INTDSP0_ACTIVEINT (0x00000001u)

#define CSL_SYS_DSPINT_RESETVAL (0x00000000u)

/* DSPINTSET */


#define CSL_SYS_DSPINTSET_INTNMI_MASK (0x00000100u)
#define CSL_SYS_DSPINTSET_INTNMI_SHIFT (0x00000008u)
#define CSL_SYS_DSPINTSET_INTNMI_RESETVAL (0x00000000u)
/*----INTNMI Tokens----*/
#define CSL_SYS_DSPINTSET_INTNMI_NOINT (0x00000000u)
#define CSL_SYS_DSPINTSET_INTNMI_SETINT (0x00000001u)


#define CSL_SYS_DSPINTSET_INTDSP3_MASK (0x00000008u)
#define CSL_SYS_DSPINTSET_INTDSP3_SHIFT (0x00000003u)
#define CSL_SYS_DSPINTSET_INTDSP3_RESETVAL (0x00000000u)
/*----INTDSP3 Tokens----*/
#define CSL_SYS_DSPINTSET_INTDSP3_NOINT (0x00000000u)
#define CSL_SYS_DSPINTSET_INTDSP3_SETINT (0x00000001u)

#define CSL_SYS_DSPINTSET_INTDSP2_MASK (0x00000004u)
#define CSL_SYS_DSPINTSET_INTDSP2_SHIFT (0x00000002u)
#define CSL_SYS_DSPINTSET_INTDSP2_RESETVAL (0x00000000u)
/*----INTDSP2 Tokens----*/
#define CSL_SYS_DSPINTSET_INTDSP2_NOINT (0x00000000u)
#define CSL_SYS_DSPINTSET_INTDSP2_SETINT (0x00000001u)

#define CSL_SYS_DSPINTSET_INTDSP1_MASK (0x00000002u)
#define CSL_SYS_DSPINTSET_INTDSP1_SHIFT (0x00000001u)
#define CSL_SYS_DSPINTSET_INTDSP1_RESETVAL (0x00000000u)
/*----INTDSP1 Tokens----*/
#define CSL_SYS_DSPINTSET_INTDSP1_NOINT (0x00000000u)
#define CSL_SYS_DSPINTSET_INTDSP1_SETINT (0x00000001u)

#define CSL_SYS_DSPINTSET_INTDSP0_MASK (0x00000001u)
#define CSL_SYS_DSPINTSET_INTDSP0_SHIFT (0x00000000u)
#define CSL_SYS_DSPINTSET_INTDSP0_RESETVAL (0x00000000u)
/*----INTDSP0 Tokens----*/
#define CSL_SYS_DSPINTSET_INTDSP0_NOINT (0x00000000u)
#define CSL_SYS_DSPINTSET_INTDSP0_SETINT (0x00000001u)

#define CSL_SYS_DSPINTSET_RESETVAL (0x00000000u)

/* DSPINTCLR */


#define CSL_SYS_DSPINTCLR_INTNMI_MASK (0x00000100u)
#define CSL_SYS_DSPINTCLR_INTNMI_SHIFT (0x00000008u)
#define CSL_SYS_DSPINTCLR_INTNMI_RESETVAL (0x00000000u)
/*----INTNMI Tokens----*/
#define CSL_SYS_DSPINTCLR_INTNMI_NOINT (0x00000000u)
#define CSL_SYS_DSPINTCLR_INTNMI_CLRINT (0x00000001u)


#define CSL_SYS_DSPINTCLR_INTDSP3_MASK (0x00000008u)
#define CSL_SYS_DSPINTCLR_INTDSP3_SHIFT (0x00000003u)
#define CSL_SYS_DSPINTCLR_INTDSP3_RESETVAL (0x00000000u)
/*----INTDSP3 Tokens----*/
#define CSL_SYS_DSPINTCLR_INTDSP3_NOINT (0x00000000u)
#define CSL_SYS_DSPINTCLR_INTDSP3_CLRINT (0x00000001u)

#define CSL_SYS_DSPINTCLR_INTDSP2_MASK (0x00000004u)
#define CSL_SYS_DSPINTCLR_INTDSP2_SHIFT (0x00000002u)
#define CSL_SYS_DSPINTCLR_INTDSP2_RESETVAL (0x00000000u)
/*----INTDSP2 Tokens----*/
#define CSL_SYS_DSPINTCLR_INTDSP2_NOINT (0x00000000u)
#define CSL_SYS_DSPINTCLR_INTDSP2_CLRINT (0x00000001u)

#define CSL_SYS_DSPINTCLR_INTDSP1_MASK (0x00000002u)
#define CSL_SYS_DSPINTCLR_INTDSP1_SHIFT (0x00000001u)
#define CSL_SYS_DSPINTCLR_INTDSP1_RESETVAL (0x00000000u)
/*----INTDSP1 Tokens----*/
#define CSL_SYS_DSPINTCLR_INTDSP1_NOINT (0x00000000u)
#define CSL_SYS_DSPINTCLR_INTDSP1_CLRINT (0x00000001u)

#define CSL_SYS_DSPINTCLR_INTDSP0_MASK (0x00000001u)
#define CSL_SYS_DSPINTCLR_INTDSP0_SHIFT (0x00000000u)
#define CSL_SYS_DSPINTCLR_INTDSP0_RESETVAL (0x00000000u)
/*----INTDSP0 Tokens----*/
#define CSL_SYS_DSPINTCLR_INTDSP0_NOINT (0x00000000u)
#define CSL_SYS_DSPINTCLR_INTDSP0_CLRINT (0x00000001u)

#define CSL_SYS_DSPINTCLR_RESETVAL (0x00000000u)

/* VSCLKDIS */


#define CSL_SYS_VSCLKDIS_VID3_MASK (0x00000800u)
#define CSL_SYS_VSCLKDIS_VID3_SHIFT (0x0000000Bu)
#define CSL_SYS_VSCLKDIS_VID3_RESETVAL (0x00000001u)
/*----VID3 Tokens----*/
#define CSL_SYS_VSCLKDIS_VID3_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_VID3_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_VID2_MASK (0x00000400u)
#define CSL_SYS_VSCLKDIS_VID2_SHIFT (0x0000000Au)
#define CSL_SYS_VSCLKDIS_VID2_RESETVAL (0x00000001u)
/*----VID2 Tokens----*/
#define CSL_SYS_VSCLKDIS_VID2_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_VID2_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_VID1_MASK (0x00000200u)
#define CSL_SYS_VSCLKDIS_VID1_SHIFT (0x00000009u)
#define CSL_SYS_VSCLKDIS_VID1_RESETVAL (0x00000001u)
/*----VID1 Tokens----*/
#define CSL_SYS_VSCLKDIS_VID1_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_VID1_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_VID0_MASK (0x00000100u)
#define CSL_SYS_VSCLKDIS_VID0_SHIFT (0x00000008u)
#define CSL_SYS_VSCLKDIS_VID0_RESETVAL (0x00000001u)
/*----VID0 Tokens----*/
#define CSL_SYS_VSCLKDIS_VID0_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_VID0_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_SPIOCNT1_MASK (0x00000080u)
#define CSL_SYS_VSCLKDIS_SPIOCNT1_SHIFT (0x00000007u)
#define CSL_SYS_VSCLKDIS_SPIOCNT1_RESETVAL (0x00000001u)
/*----SPIOCNT1 Tokens----*/
#define CSL_SYS_VSCLKDIS_SPIOCNT1_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_SPIOCNT1_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_SPIOCNT0_MASK (0x00000040u)
#define CSL_SYS_VSCLKDIS_SPIOCNT0_SHIFT (0x00000006u)
#define CSL_SYS_VSCLKDIS_SPIOCNT0_RESETVAL (0x00000001u)
/*----SPIOCNT0 Tokens----*/
#define CSL_SYS_VSCLKDIS_SPIOCNT0_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_SPIOCNT0_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_SPIOTX1_MASK (0x00000020u)
#define CSL_SYS_VSCLKDIS_SPIOTX1_SHIFT (0x00000005u)
#define CSL_SYS_VSCLKDIS_SPIOTX1_RESETVAL (0x00000001u)
/*----SPIOTX1 Tokens----*/
#define CSL_SYS_VSCLKDIS_SPIOTX1_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_SPIOTX1_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_SPIOTX0_MASK (0x00000010u)
#define CSL_SYS_VSCLKDIS_SPIOTX0_SHIFT (0x00000004u)
#define CSL_SYS_VSCLKDIS_SPIOTX0_RESETVAL (0x00000001u)
/*----SPIOTX0 Tokens----*/
#define CSL_SYS_VSCLKDIS_SPIOTX0_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_SPIOTX0_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_SPIORX1_MASK (0x00000008u)
#define CSL_SYS_VSCLKDIS_SPIORX1_SHIFT (0x00000003u)
#define CSL_SYS_VSCLKDIS_SPIORX1_RESETVAL (0x00000001u)
/*----SPIORX1 Tokens----*/
#define CSL_SYS_VSCLKDIS_SPIORX1_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_SPIORX1_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_SPIORX0_MASK (0x00000004u)
#define CSL_SYS_VSCLKDIS_SPIORX0_SHIFT (0x00000002u)
#define CSL_SYS_VSCLKDIS_SPIORX0_RESETVAL (0x00000001u)
/*----SPIORX0 Tokens----*/
#define CSL_SYS_VSCLKDIS_SPIORX0_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_SPIORX0_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_CRG1_MASK (0x00000002u)
#define CSL_SYS_VSCLKDIS_CRG1_SHIFT (0x00000001u)
#define CSL_SYS_VSCLKDIS_CRG1_RESETVAL (0x00000001u)
/*----CRG1 Tokens----*/
#define CSL_SYS_VSCLKDIS_CRG1_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_CRG1_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_CRG0_MASK (0x00000001u)
#define CSL_SYS_VSCLKDIS_CRG0_SHIFT (0x00000000u)
#define CSL_SYS_VSCLKDIS_CRG0_RESETVAL (0x00000001u)
/*----CRG0 Tokens----*/
#define CSL_SYS_VSCLKDIS_CRG0_ENABLE (0x00000000u)
#define CSL_SYS_VSCLKDIS_CRG0_DISABLE (0x00000001u)

#define CSL_SYS_VSCLKDIS_RESETVAL (0x00000FFFu)

/* ARMINT */


#define CSL_SYS_ARMINT_INTARM0_MASK (0x00000001u)
#define CSL_SYS_ARMINT_INTARM0_SHIFT (0x00000000u)
#define CSL_SYS_ARMINT_INTARM0_RESETVAL (0x00000000u)
/*----INTARM0 Tokens----*/
#define CSL_SYS_ARMINT_INTARM0_NOINT (0x00000000u)
#define CSL_SYS_ARMINT_INTARM0_ACTIVEINT (0x00000001u)

#define CSL_SYS_ARMINT_RESETVAL (0x00000000u)

/* ARMINTSET */


#define CSL_SYS_ARMINTSET_INTARM0_MASK (0x00000001u)
#define CSL_SYS_ARMINTSET_INTARM0_SHIFT (0x00000000u)
#define CSL_SYS_ARMINTSET_INTARM0_RESETVAL (0x00000000u)
/*----INTARM0 Tokens----*/
#define CSL_SYS_ARMINTSET_INTARM0_NOINT (0x00000000u)
#define CSL_SYS_ARMINTSET_INTARM0_SETINT (0x00000001u)

#define CSL_SYS_ARMINTSET_RESETVAL (0x00000000u)

/* ARMINTCLR */


#define CSL_SYS_ARMINTCLR_INTARM0_MASK (0x00000001u)
#define CSL_SYS_ARMINTCLR_INTARM0_SHIFT (0x00000000u)
#define CSL_SYS_ARMINTCLR_INTARM0_RESETVAL (0x00000000u)
/*----INTARM0 Tokens----*/
#define CSL_SYS_ARMINTCLR_INTARM0_NOINT (0x00000000u)
#define CSL_SYS_ARMINTCLR_INTARM0_CLRINT (0x00000001u)

#define CSL_SYS_ARMINTCLR_RESETVAL (0x00000000u)

/* ARMWAIT */


#define CSL_SYS_ARMWAIT_ARMWAIT_MASK (0x00000001u)
#define CSL_SYS_ARMWAIT_ARMWAIT_SHIFT (0x00000000u)
#define CSL_SYS_ARMWAIT_ARMWAIT_RESETVAL (0x00000001u)
/*----ARMWAIT Tokens----*/
#define CSL_SYS_ARMWAIT_ARMWAIT_DISABLE (0x00000000u)
#define CSL_SYS_ARMWAIT_ARMWAIT_ENABLE (0x00000001u)

#define CSL_SYS_ARMWAIT_RESETVAL (0x00000001u)

/* SEC_PSEUDO0 */


#define CSL_SYS_SEC_PSEUDO0_RESETVAL (0x00000000u)

/* SEC_PSEUDO1 */


#define CSL_SYS_SEC_PSEUDO1_RESETVAL (0x00000000u)

#endif
