/*
 * nor.h
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

/** \file   nor.h
    \brief  DaVinci Secondary boot-loader, NOR Header file

    NOTE: THIS FILE IS PROVIDED FOR INITIAL DEMO RELEASE AND MAY BE
          REMOVED AFTER THE DEMO OR THE CONTENTS OF THIS FILE ARE SUBJECT
          TO CHANGE.

    @author    Amit Chatterjee
    @version    0.1 - Created
**/

#ifndef _NOR_H_
#define _NOR_H_

#include <tistdtypes.h>
#include <cslr_emif.h>
#include <cslr_edma.h>

/* NOR FLASH ADDRESS */
#define NOR_BASE_ADDR  ((volatile Uint16*)0x02000000)

//
//Structs
//
typedef struct _PageInfo
{
    Uint32	reserved;
    Uint8  	BlockReserved;    
    Uint8  	BadBlockFlag;    
    Uint16	reserved2;
}PageInfo, *PPageInfo;

typedef struct  
{
	Uint32 ReturnValue;
	Uint32 ReadAddress;
	Uint32 WriteAddress;
	Uint32 Size;          
} Download_Parms, *PDownload_Parms;

#define NO_ERROR            0
#define CORRECTED_ERROR     1
#define ECC_ERROR           2
#define UNCORRECTED_ERROR   3

//  Status bit pattern
#define STATUS_READY                0x40
#define STATUS_ERROR                0x01

// Flash ID Commands AMD
#define AMD_ID_CMD0        ((Uint16)0xAA)     // AMD ID CMD 0
#define AMD_CMD0_ADDR       0x555          // AMD CMD0 Offset 
#define AMD_ID_CMD1        ((Uint16)0x55)     // AMD ID CMD 1
#define AMD_CMD1_ADDR	    0x2AA          // AMD CMD1 Offset 
#define AMD_ID_CMD2        ((Uint16)0x90)     // AMD ID CMD 2
#define AMD_CMD2_ADDR	    0x555          // AMD CMD2 Offset 
#define AMD_MANF_ID        ((Uint16)0x01)     // AMD Manf ID expected
#define AMD_DEVICE_ID_MULTI   ((Uint16)0x227E)// Indicates Multi-Address Device ID
#define AMD_DEVICE_ID_OFFSET 0x1 
#define AMD_DEVICE_ID_OFFSET1 0x0E         // First Addr for Multi-Address ID 
#define AMD_DEVICE_ID_OFFSET2 0x0F         // Second Addr for Multi-Address ID 
#define AMD_DEVICE_RESET   ((Uint16)0x00F0)   // AMD Device Reset Command
#define AMD_ERASE_CMD0    ((Uint16)0xAA)     
#define AMD_ERASE_CMD1    ((Uint16)0x55)     
#define AMD_ERASE_CMD2    ((Uint16)0x80)     
#define AMD_ERASE_CMD3    ((Uint16)0xAA)     	// AMD29LV017B Erase CMD 3
#define AMD_ERASE_CMD4    ((Uint16)0x55)     	// AMD29LV017B Erase CMD 4
#define AMD_ERASE_CMD5    ((Uint16)0x10)     	// AMD29LV017B Erase CMD 5
#define AMD_ERASE_DONE    ((Uint16)0xFFFF)     // AMD29LV017B Erase Done
#define AMD_ERASE_BLK_CMD0	((Uint16)0xAA) 
#define AMD_ERASE_BLK_CMD1	((Uint16)0x55) 
#define AMD_ERASE_BLK_CMD2	((Uint16)0x80) 							
#define AMD_ERASE_BLK_CMD3	((Uint16)0xAA) 
#define AMD_ERASE_BLK_CMD4	((Uint16)0x55) 
#define AMD_ERASE_BLK_CMD5	((Uint16)0x30) 
#define AMD_PROG_CMD0    ((Uint16)0xAA) 
#define AMD_PROG_CMD1    ((Uint16)0x55) 
#define AMD_PROG_CMD2    ((Uint16)0xA0) 
#define AMD2_ERASE_CMD0    ((Uint16)0x00AA)     // AMD29DL800B Erase CMD 0
#define AMD2_ERASE_CMD1    ((Uint16)0x0055)     // AMD29DL800B Erase CMD 1
#define AMD2_ERASE_CMD2    ((Uint16)0x0080)     // AMD29DL800B Erase CMD 2
#define AMD2_ERASE_CMD3    ((Uint16)0x00AA)     // AMD29DL800B Erase CMD 3
#define AMD2_ERASE_CMD4    ((Uint16)0x0055)     // AMD29DL800B Erase CMD 4
#define AMD2_ERASE_CMD5    ((Uint16)0x0030)     // AMD29DL800B Erase CMD 5
#define AMD2_ERASE_DONE    ((Uint16)0x00FF)     // AMD29DL800B Erase Done
#define AMD_WRT_BUF_LOAD_CMD0           ((Uint16)0xAA) 
#define AMD_WRT_BUF_LOAD_CMD1           ((Uint16)0x55) 
#define AMD_WRT_BUF_LOAD_CMD2           ((Uint16)0x25) 
#define AMD_WRT_BUF_CONF_CMD0           ((Uint16)0x29) 
#define AMD_WRT_BUF_ABORT_RESET_CMD0    ((Uint16)0xAA) 
#define AMD_WRT_BUF_ABORT_RESET_CMD1    ((Uint16)0x55) 
#define AMD_WRT_BUF_ABORT_RESET_CMD2    ((Uint16)0xF0) 

// For AMD Flash 
#define NUM_AMD_SECTORS 8  // Only using the first 8 8-KB sections (64 KB Total)
#define AMD_ADDRESS_CS_MASK		0xFE000000	//--AMD-- Set-up as 0xFE000000 per Jon Hunter (Ti)

/* Prototypes of functions for NAND flash */
void NORInit (void);
void NORWriteNBytes(Uint8* startAddr, Uint32 numBytes, Uint8* srcAddr);
Int EraseNORFlash(Uint32 start_address, Uint32 size);

#endif //_NOR_H_
