/*
 * platform.h
 * Definitions for boot loader.
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef _PLATFORM_H_
#define _PLATFORM_H_

#include <tistdtypes.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
	volatile Uint32 PID;
	volatile Uint8 RSVD0[224];
	volatile Uint32 RSTYPE;
	volatile Uint8 RSVD1[24];
	volatile Uint32 PLLCTL;
	volatile Uint8 RSVD2[12];
	volatile Uint32 PLLM;
	volatile Uint8 RSVD3[4];
	volatile Uint32 PLLDIV1;
	volatile Uint32 PLLDIV2;
	volatile Uint32 PLLDIV3;
	volatile Uint8 RSVD4[4];
	volatile Uint32 POSTDIV;
	volatile Uint32 BPDIV;
	volatile Uint8 RSVD5[8];
	volatile Uint32 PLLCMD;
	volatile Uint32 PLLSTAT;
	volatile Uint32 ALNCTL;
	volatile Uint32 DCHANGE;
	volatile Uint32 CKEN;
	volatile Uint32 CKSTAT;
	volatile Uint32 SYSTAT;
	volatile Uint8 RSVD6[12];
	volatile Uint32 PLLDIV4;
	volatile Uint32 PLLDIV5;
	volatile Uint32 PLLDIV6;
	volatile Uint32 PLLDIV7;
	volatile Uint32 PLLDIV8;
	volatile Uint32 PLLDIV9;
} CSL_PLLRegs;

typedef volatile CSL_PLLRegs *CSL_PLLRegsOvly;
#define CSL_PLL1_REGS       	((CSL_PLLRegsOvly) 0x01C40800)
#define CSL_PLL2_REGS       	((CSL_PLLRegsOvly) 0x01C40C00)

#define PLL_LOCK_COUNT		0x0000B5A4
#define PLL_RESET_COUNT		0x00001D4C

#define PLL_CLKMODE_MASK	(~0x00000100)
#define PLL_BYPASS_MASK		0xFFFFFFCE
#define CLR_PLLEN_SRC		~0x00000020
#define CLR_PLLEN		~0x00000001
#define PLL_RESET_MASK		0x00000008
#define PLL_PWRUP_MASK		0xFFFFFFFD
#define PLL_DISABLE_ENABLE_MASK	0xFFFFFFEF
#define PLLDIS			0x00000010

#if defined UBL_CONFIG_729MHZ && defined UBL_CONFIG_1GHZ
#error Config options UBL_CONFIG_729MHZ and UBL_CONFIG_1GHZ cannot be defined together
#endif

/*
 * Generally we will need to set-up system PLL when default divider or
 * multiplier values need to be changed (e.g., overclocking) or when the PLL1
 * is not setup (e.g., no ROM bootloader ???) before UBL
 */
#if defined UBL_CONFIG_729MHZ || defined UBL_CONFIG_1GHZ		 
#define UBL_PLL1_SETUP
#endif

#if defined UBL_CONFIG_1GHZ
#define CFG_PLL1_PLLM		0x1D		/* 33MHz * 30 =  990MHz */
#define CFG_PLL2_PLLM		0x17		/* 33MHz * 24 =  792MHz */
#elif defined UBL_CONFIG_729MHZ
#define CFG_PLL1_PLLM		0x15		/* 33MHz * 22 =  726MHz */
#define CFG_PLL2_PLLM		0x11		/* 33MHz * 18 =  594MHz */
#else
#define CFG_PLL1_PLLM		0x15		/* 27MHz * 22 =  594MHz */
#define CFG_PLL2_PLLM		0x15		/* 27MHz * 22 =  594MHz */
#endif

/*
 *  PLL1 post dividers
 *           Div1: (Fixed @ /1)DSP
 *           Div2: (Fixed @ /2)ARM/PCI/GraphicsEngine/HD-VICP0-1/EDMA/SCR
 *           Div3: (Fixed @ /4)Peripherals
 *           Div4: ATA
 *           Div5: SYSCLK5
 *           Div6: SYSCLK6
 *           Div7: SYSCLK7
 *           Div8: SYSCLK8
 *           Div9: VLYNQ
 */
#define PLL_1_DIV1_VAL		0x00008000
#define PLL_1_DIV2_VAL		0x00008001
#define PLL_1_DIV3_VAL		0x00008003

#ifdef UBL_CONFIG_1GHZ
#define PLL_1_DIV4_VAL		0x00008006
#define PLL_1_DIV5_VAL		0x00008009
#define PLL_1_DIV6_VAL		0x00008009
#define PLL_1_DIV8_VAL		0x00008009
#define PLL_1_DIV9_VAL		0x00008009
#elif defined UBL_CONFIG_729MHZ
#define PLL_1_DIV4_VAL		0x00008006   /* Changed from 5 to 6 for 729MHz */
#define PLL_1_DIV5_VAL		0x00008009   /* Changed from 7 to 9 for 729MHz */
#define PLL_1_DIV6_VAL		0x00008009   /* Changed from 7 to 9 for 729MHz */
#define PLL_1_DIV8_VAL		0x00008009   /* Changed from 7 to 9 for 729MHz */
#define PLL_1_DIV9_VAL		0x00008006   /* Changed from 5 to 6 for 729MHz */
#else
#define PLL_1_DIV4_VAL		0x00008005
#define PLL_1_DIV5_VAL		0x00008007
#define PLL_1_DIV6_VAL		0x00008007
#define PLL_1_DIV8_VAL		0x00008007
#define PLL_1_DIV9_VAL		0x00008005
#endif

#define PLL_2_DIV2_VAL		0x00008000
#define PLL_2_DIV1_VAL		0x00008000

#endif //_PLATFORM_H_
