/*
 * emifconfig.c
 * NAND and EMIF Configuration file
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include <bootloader.h>

#ifdef UBL_USE_NAND_BOOT
#include <nand.h>

extern NAND_INFO gNandInfo;

void NANDConfig (void) {
	/* Enable AEMIF Power */
	LPSCEnable(PD0,LPSC_AEMIF);

      /* We are leaving the CSL_EMIF_0_REGS->AWCCR = 0x80 
	   This is the default setting. Hibari sets it to 0x0F
	*/
      /*Aysnchronous bank 1 is used for NAND CS2 */
      if (gNandInfo.nand_width ) {
		//CSL_EMIF_0_REGS->AB1CR = 0x3FFE219D;//16 bit->01
		CSL_EMIF_0_REGS->AB1CR = 0x3FFFFFFD;//16 bit->01
      } else {
		//CSL_EMIF_0_REGS->AB1CR = 0x3FFE219C;//8 bit->00
		CSL_EMIF_0_REGS->AB1CR = 0x3FFFFFFC;//8 bit->00
	}

      /* configuring the CS2(bit no.0) for NAND) */
      CSL_EMIF_0_REGS->AWCCR =  0x10000000; 
      CSL_EMIF_0_REGS->NANDFCR =  0x1; 
}

Uint32 NANDSpareECCRead(Uint8* readPtr) {
        Uint32 spareECCValue;
	if(gNandInfo.nand_width)
    	        // 16 bit NAND
    	        spareECCValue = (*((Uint16*)(&readPtr[0]))<<16)|(*((Uint16*)(&readPtr[2]))); 
        else
    	        // 8 bit NAND
    	        spareECCValue = (readPtr[0]<<24)|(readPtr[1]<<16)|(readPtr[2]<<8)|readPtr[3]; 
    	
	return spareECCValue;
}

void EMIFEnableFastMode() {
	// if 8_16 = 1 then CSL_EMIF_0_REGS->AB1CR = 0x1
	// else CSL_EMIF_0_REGS->AB1CR = 0x0
 	CSL_EMIF_0_REGS->AB1CR &= 0x1;
}

void EMIFDisableFastMode() {
	// if 8_16 = 1 then CSL_EMIF_0_REGS->AB1CR = 0x3FFFFFFD
	// else CSL_EMIF_0_REGS->AB1CR = 0x3FFFFFFC
	CSL_EMIF_0_REGS->AB1CR |= 0x3FFFFFFC;
}

#endif /* UBL_USE_NAND_BOOT | UBL_USE_NOR_BOOT */

