/*
 * nand.c
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

/** \file   nand.c
    \brief  DaVinci Secondary boot-loader, NAND driver file

    NOTE: THIS FILE IS PROVIDED FOR INITIAL DEMO RELEASE AND MAY BE
          REMOVED AFTER THE DEMO OR THE CONTENTS OF THIS FILE ARE SUBJECT
          TO CHANGE.

    @author    Amit Chatterjee
    @version    0.1 - Modified from ROM Boot Loader
**/

#include <bootloader.h>

#ifdef UBL_USE_NAND_BOOT

#include <nand.h>

volatile NAND_INFO	gNandInfo;
extern NAND_BOOT gNandBoot;				 /* structure for holding details about UBL stored in NAND */
extern Uint32 gDMA;

/* Details of NAND device sizes supported */
const NAND_DEVICE_INFO   gNandDevInfo[] = {
/*  devid,p_cnt,p_byte1,blk_shift, addr_cycles */
  	{0x6E, 16, 	256+8, 	12, 		3},  /* 1 MB */
  	{0x68, 16, 	256+8, 	12, 		3},  /* 1 MB */
  	{0xEC, 16, 	256+8, 	12, 		3},  /* 1 MB */
  	{0xE8, 16, 	256+8, 	12, 		3},  /* 1 MB */
  	{0xEA, 16, 	256+8, 	12, 		3},  /* 2 MB */
    {0xE3, 16, 	512+16, 12, 		3},	 /* 4 MB */
    {0xE5, 16, 	512+16, 12, 		3},	 /* 4 MB */
    {0xE6, 16, 	512+16, 12, 		3},	 /* 8 MB */
    {0x39, 16, 	512+16, 12, 		3},	 /* 8 MB */
    {0x6B, 16, 	512+16, 12, 		3},	 /* 8 MB */
    {0x73, 32, 	512+16, 13, 		3},	 /* 16 MB */
    {0x33, 32, 	512+16, 13, 		3},	 /* 16 MB */
    {0x75, 32, 	512+16, 13, 		3},	 /* 32 MB */
    {0x35, 32, 	512+16, 13, 		3},	 /* 32 MB */
	{0x43, 32, 	512+16, 12, 		3},  /* 16 MB 0x1243 */
	{0x45, 32, 	512+16, 12, 		3},  /* 32 MB 0x1245 */
	{0x53, 32, 	512+16, 12, 		3},  /* 16 MB 0x1253 */
	{0x55, 32, 	512+16, 12, 		3},  /* 32 MB 0x1255 */
    {0x36, 32, 	512+16, 13, 		4},	 /* 64 MB */
    {0x79, 32, 	512+16, 13, 		4},	 /* 128 MB */
  	{0x71, 32, 	512+16, 13, 		4},	 /* 256 MB */
	{0x46, 32, 	512+16, 13, 		4},  /* 64 MB 0x1346 */
	{0x56, 32, 	512+16, 13, 		4},  /* 64 MB 0x1356 */
	{0x74, 32, 	512+16, 13, 		4},  /* 128 MB 0x1374 */
    {0xA1, 64, 	2048+64,22, 		4},	 /* 128 MB - Big Block */
    {0xF1, 64,  2048+64,22,         4},      /* 128 MB - Big Block, ST Micro */
 	{0xAA, 64, 	2048+64,22, 		5},	 /* 256 MB - Big Block */
 	{0xDA, 64, 	2048+64,22, 		5},	 /* 256 MB - Big Block */
 	{0xDC, 64, 	2048+64,22, 		5},	 /* 512 MB - Big Block */
 	{0x76, 32, 	512+16, 13, 		4},	 /* 64 MB */
 	{0xAC, 64, 	2048+64,22, 		5},  /* 512 MB - Big Block */
	{0xB1, 64, 	2048+64,22, 		4},  /* 128 MB - Big Block 0x22B1 */
  	{0xC1, 64, 	2048+64,22, 		4},  /* 128 MB - Big Block 0x22C1 */
};

Int32 nand_erase_timeout = ( 0x00100000 );

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _NAND_readECC( )                                                        *
 *      Read ECC calcualtions                                               *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Uint32 _NAND_readECC( )
{
    return EMIFA_NANDF1ECC;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _NAND_startECC( )                                                       *
 *      Start ECC calcualtions                                              *
 *                                                                          *
 * ------------------------------------------------------------------------ */
void _NAND_startECC( )
{
	EMIFA_NANDFCR |= 0x0001;
	_NAND_readECC( );
	EMIFA_NANDFCR |= 0x0100;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _NAND_CMD( command )                                                    *
 *      Issue command                                                       *
 *                                                                          *
 * ------------------------------------------------------------------------ */
void _NAND_CMD( Uint32 command )
{
    *NAND_CMD_ADDR = command;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _NAND_PAGE_ADDR( page_addr )                                            *
 *      Issue page address                                                  *
 *                                                                          *
 * ------------------------------------------------------------------------ */
void _NAND_PAGE_ADDR( Uint32 page_addr )
{
  	/* [1st]7:0 -> [2nd]11:8 -> [3rd]19:12 -> [4th]27:20 */
    *NAND_ALE_ADDR = ( page_addr >> 0 );
    *NAND_ALE_ADDR = ( page_addr >> 8 ) & 0x0f;
    *NAND_ALE_ADDR = ( page_addr >> 12 );
    *NAND_ALE_ADDR = ( page_addr >> 20 );
}


/* Initialze NAND interface and find the details of the NAND used */
Uint32 NANDInit()
{
        Uint32 error;
	/* Setting the nand_width = 0(8 bit NAND) or 1(16 bit NAND). AEMIF CS2 bus Width
	   is given by the BOOTCFG(bit no.8)
         */
	gNandInfo.nand_width = ((*BOOTCFG)&(NAND_TYPE_MASK_0X00000100))>>8;

	/* initialize NAND interface */
	NANDConfig();

	/* Send reset command to NAND */
	*NAND_CMD_ADDR = NAND_RST;
	waitloop(10);
	
/*	if(NANDWaitRdy() != E_PASS) {
		error = E_FAIL;
	}
*/	
	if ( _NAND_busywait( 0x100000 ) )
		return E_FAIL;

	error = NANDGetDetails();

	return error;
}

/* NAND write. Used to send CMD to the NAND flash */
void NANDWriteByte (Uint16 nandWidth, void *ptr, Uint16 data)
{
        if (nandWidth) {
                *(volatile Uint16*)ptr = data;
        } else {
                *(volatile Uint8*)ptr = (Uint8)data;
        }
}

void NANDReadNBytes(Uint32 numBytes, Uint8* destAddr)
{
        Uint32 i;

	/* Starting the ECC in the NANDFCR register for CS2(bit no.8) */
	NANDECCRead();
	NANDECCStart();

	if (gNandInfo.nand_width) {
                /* 16-bit NAND */
		for(i=0;i<(numBytes/2);i++) {
			/* NANDRead done directly without checking for nand_width */
	    	*(Uint16*)destAddr = *((volatile Uint16*)NAND_DATA_ADDR);
			destAddr += 2;
		}
    } else {
    	/* 8-bit NAND */
        for (i=0; i < numBytes; i++) {
        	/* NANDRead done directly without checking for nand_width */
			*destAddr = (*NAND_DATA_ADDR);
	    	destAddr++;
	    }
	}
}

Uint32 NANDReadNBytesDMA(Uint32 numBytes, Uint8* destAddr)
{
	Uint32 status = 0;
	volatile Uint32 count = DMA_TIMEOUT;
	/* Starting the ECC in the NANDFCR register for CS2(bit no.8) */
	NANDECCRead();
	NANDECCStart();

	CSL_EDMACC_0_REGS->PARAMENTRY[0].OPT = 0x00100004;
	CSL_EDMACC_0_REGS->PARAMENTRY[0].SRC = 0x42000000;
	CSL_EDMACC_0_REGS->PARAMENTRY[0].SRC_DST_BIDX = 0x00080000;
	CSL_EDMACC_0_REGS->PARAMENTRY[0].LINK_BCNTRLD = 0x0;
	CSL_EDMACC_0_REGS->PARAMENTRY[0].SRC_DST_CIDX = 0x0;
	CSL_EDMACC_0_REGS->PARAMENTRY[0].CCNT = 1;

	CSL_EDMACC_0_REGS->PARAMENTRY[0].A_B_CNT = ((numBytes/8)<<16) | (0x8);

	CSL_EDMACC_0_REGS->PARAMENTRY[0].DST = (Uint32)((&destAddr[0]));

	CSL_EDMACC_0_REGS->SHADOW[0].ICR = 0xFFFFFFFF;
	CSL_EDMACC_0_REGS->SHADOW[0].EESR |= 0x1;
	CSL_EDMACC_0_REGS->SHADOW[0].ESR  |= 0x1;

	/* check for the status to be ready */
	do {
		status = ((CSL_EDMACC_0_REGS->SHADOW[0].IPR) & (0x00000001));
		count --;
	} while (!status && count > 0);

	if(count == 0)
		return E_TIMEOUT;
	else
		return E_PASS;

}

/* This function reads the spare area of the specified NAND page. Note: This  */
Int32 NANDReadSpareArea( Uint32 page_number , Uint8 *spare_data )
{
	Uint32 page_addr;
	Uint32 i;

    /* This is way to do it for large block. Needs improvement. */
    page_addr = page_number * 2048 * 2;

	/* Add the offset of the spare area. The first byte/word of the spare
	 * area is the "bad block" indicator */
    page_addr = page_addr + 2048;

    /* Read the spare area of the page */
    _NAND_CMD( NAND_LO_PAGE );          // Read page
    _NAND_PAGE_ADDR( page_addr );       // Page address

   /* Use Read confirm? */
	_NAND_CMD( NAND_READ_30H );      // Read Confirm

   if ( _NAND_busywait( 0x00100000 ) )
       return -1;

   /* Read spare area in 8 bit mode */
   for ( i = 0; i < 64; i++ )
   {
	   *spare_data = (*NAND_DATA_ADDR);
	   spare_data = spare_data + 1;
   }

   return 0;
}

/* This function reads the spare area of the specified NAND page */
Int16 NANDCheckBadBlock( Uint32 block_number )
{
    Uint32 page_number;
    Uint8  spare_area[64];
	Uint32 k;

	for (k = 0; k < 1; k++)
	{
		page_number = (block_number * 64) + k;

		if ( NANDReadSpareArea( page_number , spare_area ) == -1 )
			return -1;

			if ((spare_area[0] != 0xFF) && (spare_area[1] != 0xFF))
				return -1;
	} /* for k */

    return 0;
}

/* Get details of the NAND flash used from the id and the table of NAND */
Uint32 NANDGetDetails()
{
	Uint8 deviceID,i;
	Uint32 foundNAND = NAND_NOT_FOUND;

	/* read device ID */
	*NAND_CMD_ADDR =  NAND_RDID;/* Read ID Command */
	*NAND_ALE_ADDR =  NAND_RDIDADD;/* Send ID address */
	waitloop(10);

	/* Always reading the ID alone in 8 bit mode */
	i			= (*NAND_DATA_ADDR);
	deviceID 	= (*NAND_DATA_ADDR);
	i	 		= (*NAND_DATA_ADDR);
	i 			= (*NAND_DATA_ADDR);

	/* Search for the NAND details in the table */
	for(i=0;((i<MAX_NAND_SUPPORTED) && (foundNAND == NAND_NOT_FOUND));i++) {
		if(deviceID == gNandDevInfo[i].dev_id) {
			foundNAND = NAND_FOUND;
			gNandInfo.dev_code = deviceID;
			gNandInfo.page_cnt = gNandDevInfo[i].p_cnt;
			gNandInfo.page_size = gNandDevInfo[i].p_byte1;
			gNandInfo.blk_shift = gNandDevInfo[i].blk_shift;
			gNandInfo.addr_cycles = gNandDevInfo[i].addr_cycles;
			if(gNandInfo.page_size > 528) {
				gNandInfo.page_shift = 16;
				gNandInfo.big_block = 1;
			} else {
				gNandInfo.page_shift = 8;
				gNandInfo.big_block = 0;
			}
		}
	}
	if(foundNAND == NAND_NOT_FOUND) {
		/* Default configuration */
		/* For SAMSUNG/RENESAS and other. We dont support Toshiba */
		gNandInfo.dev_code 		= UNKNOWN_NAND;
		gNandInfo.page_cnt 		= 64;
		gNandInfo.page_size 	= 2112;
		gNandInfo.blk_shift 	= 22;
		gNandInfo.big_block 	= 1;
		gNandInfo.addr_cycles 	= 4;
		gNandInfo.page_shift 	= 16;
	}

	return E_PASS;
}

/* ------------------------------------------------------------------------ *
 *                                                                          *
 *  _NAND_read8( rx, use_ecc )                                              *
 *      Read a page from NAND                                               *
 *                                                                          *
 *      Inputs:                                                             *
 *          rx         = address of rx buffer [ any address ]               *
 *          use_ecc    = use ECC?                                           *
 *                                                                          *
 *      Return:                                                             *
 *          =0  pass                                                        *
 *          >0  failed - bad pages                                          *
 *          -1  timeout                                                     *
 *                                                                          *
 * ------------------------------------------------------------------------ */
Uint32 _NAND_read8( Uint32 rx, Uint32 use_ecc )
{
    Int16 i, j;
    volatile Uint8* rx8 = ( volatile Uint8* )rx;

    /* Spare + ECC */

    Uint32 retcode = 0;
	Uint32 eccValue[4];
	Uint32 spareValue;
	
	for (i = 0; i < 4; i++) {
				NANDReadNBytes(512, (Uint8 *)&rx8[512*i]);
				eccValue[i] = ((NANDECCRead())&(0x0FFF0FFF));
			}
		NANDReadNBytes(64, (Uint8 *)&rx8[2048]);
		for (j = 0; j < 4; j++) {
			/* ECC values read from (2056+j*16+8)*/
		spareValue =
			(NANDSpareECCRead((Uint8 *)&rx8[2056+(j*16)])&(0xFFF0FFF));
		if (eccValue[j] != spareValue)
			return retcode++; /* E_FAIL */
		}

    return retcode;
    }

    

/* Routine to read a page from NAND */
Uint32 NANDReadPage(Uint32 start_page, Uint32 *rx, Uint32 page_count) {
    Uint32 i;
    Uint32 page_addr;
    Uint32 retcode = 0;

    for ( i = start_page ; i < start_page + page_count ; i++ )
    {
        /* Fix for large page addressing */
        page_addr = (i * 2048 * 2);

        /* Read a single page */
        _NAND_CMD( NAND_LO_PAGE );              // Read page
        _NAND_PAGE_ADDR( page_addr );       // Page address

        /* Use Read confirm? */
        if ( 1 )
            _NAND_CMD( NAND_READ_30H );  // Read Confirm

        if ( _NAND_busywait( 0x00100000 ) )
            return E_FAIL;

        /* Read page in 8 bit mode */
        if ( gNandInfo.nand_width == 0 )
            retcode += _NAND_read8((Uint32) rx, 1);
	}
    return retcode;
}

Int16 _NAND_busywait( Int32 timeout )
{
    /* Wait while the device is busy */
    while( ( NAND_READ_RB == 0 ) && ( timeout-- > 0 ) );

    waitloop( 500 );

    if ( timeout == 0 )
        return -1;

    return 0;
}

/* Wait for the status to be ready
Polling for the pad_wait_i(bit 0) of NANDFSR */
Uint32 NANDWaitRdy()
{
	volatile Uint32 cnt;
	Uint32 status;
  	cnt = NAND_TIMEOUT;

	waitloop(40);

  	do {
    	        status = (CSL_EMIF_0_REGS->NANDFSR & 1);
                cnt--;
  	} while((cnt>0) && !status);

	waitloop(40);

  	if(cnt == 0)
  		return E_FAIL;

 	return E_PASS;
}


/* Wait for the status to be ready in register
 There were some problems reported in DM320 with Ready/Busy pin
 not working with all NANDs. So this check has also been added */
Uint32 NANDWaitRdyReg()
{
        volatile Uint32 cnt;
	Uint32 status;
        *NAND_CMD_ADDR = NAND_STATUS;
        status = *NAND_DATA_ADDR;
        cnt = NAND_TIMEOUT;

  	do {
                *NAND_CMD_ADDR = NAND_STATUS;
                status = *NAND_DATA_ADDR;
                cnt--;
  	} while((cnt>0) && !status);

	if(cnt == 0)
		return E_FAIL;

	return E_PASS;
}

/* Routine to Write a page to NAND */
Uint32 NANDWritePage(Uint32 blkAddr, Uint32 page, Uint8 *src)
{
	Uint16 i,j;
	Uint32 addr;
	Uint32 eccValue[4];

	/* Starting the ECC in the NANDFCR register for CS2(bit no.8) */
	NANDECCRead();
	NANDECCStart();

	NANDWriteByte(gNandInfo.nand_width,(void*)NAND_CMD_ADDR, NAND_PGRM_START);

	if(gNandInfo.addr_cycles == 5) {
		addr = blkAddr << (gNandInfo.blk_shift-16) | page;
		/* [vig] writing 8 bit at a time */
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,0x00);
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,0x00);
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,addr & 0xff);
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff00)>>8));
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff0000)>>16));
	} else if(gNandInfo.addr_cycles == 4) {
		addr = blkAddr << gNandInfo.blk_shift | page << gNandInfo.page_shift;
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,addr & 0xff);
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff00)>>8));
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff0000)>>16));
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff000000)>>24));
	} else {
		addr = blkAddr << gNandInfo.blk_shift | page << gNandInfo.page_shift;
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,addr & 0xff);
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff00)>>8));
		NANDWriteByte(0,(void*)NAND_ALE_ADDR,((addr & 0xff0000)>>16));
	}

	/* Starting the ECC in the NANDFCR register for CS2(bit no.8) */
	NANDECCRead();
	NANDECCStart();

	/* Do not have an option to write 264 page size */
	/* Write to Page of size 528 */
	if (gNandInfo.page_size == 528) {
                if (gNandInfo.nand_width) {
		/* 16-bit NAND */
		        for(i=0;i<512;i+=2)
			        NANDWriteByte(1,(void*)NAND_DATA_ADDR,*((Uint16*)&src[i]));
		} else {
                        /* 8-bit NAND */
			for(i=0;i<512;i++)
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,src[i]);
		}

		eccValue[0] = ((NANDECCRead())&(0x0FFF0FFF));
		if (gNandInfo.nand_width) {
                        /* 16-bit NAND */
			NANDWriteByte(1,(void*)NAND_DATA_ADDR,(eccValue[0]&0xFFFF0000)>>16);
			NANDWriteByte(1,(void*)NAND_DATA_ADDR,(eccValue[0]&0xFFFF));
			for(i=0;i<6;i++)
				NANDWriteByte(1,(void*)NAND_DATA_ADDR,0xFFFF);
		} else {
                        /* 8-bit NAND */
			NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[0]&0xFF000000)>>24);
			NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[0]&0xFF0000)>>16);
			NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[0]&0xFF00)>>8);
			NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[0]&0xFF));
			for(i=0;i<12;i++)
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,0xFF);
		}
	} else if (gNandInfo.page_size == 2112) {
		j = 0;
		if (gNandInfo.nand_width) {
			for(i=0;i<2048;i+=2) {
				NANDWriteByte(1,(void*)NAND_DATA_ADDR,*((Uint16*)&src[i]));
				if((i == 510)||(i == 1022)||(i == 1534)||(i == 2046)) {
					eccValue[j] = ((NANDECCRead())&(0x0FFF0FFF));
					NANDECCStart();
					j++;
				}
			}
		} else {
			for(i=0;i<2048;i++) {
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,src[i]);

				if((i == 511)||(i == 1023)||(i == 1535)||(i == 2047)) {
					eccValue[j] = ((NANDECCRead())&(0x0FFF0FFF));
					NANDECCStart();
					j++;
				}
			}
		}

		for(j=0;j<4;j++) {
			if (gNandInfo.nand_width) {
				/* 16-bit NAND */
				for(i=0;i<4;i++)
					NANDWriteByte(1,(void*)NAND_DATA_ADDR,0xFFFF);
				NANDWriteByte(1,(void*)NAND_DATA_ADDR,(eccValue[j]&0xFFFF0000)>>16);
				NANDWriteByte(1,(void*)NAND_DATA_ADDR,(eccValue[j]&0xFFFF));
				for(i=0;i<2;i++)
					NANDWriteByte(1,(void*)NAND_DATA_ADDR,0xFFFF);
			} else {
				/* 8-bit NAND */
				for(i=0;i<8;i++)
					NANDWriteByte(0,(void*)NAND_DATA_ADDR,0xFF);
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[j]&0xFF000000)>>24);
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[j]&0xFF0000)>>16);
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[j]&0xFF00)>>8);
				NANDWriteByte(0,(void*)NAND_DATA_ADDR,(eccValue[j]&0xFF));
				for(i=0;i<4;i++)
					NANDWriteByte(0,(void*)NAND_DATA_ADDR,0xFF);
			}
		}
	}

	NANDWriteByte(gNandInfo.nand_width,(void*)NAND_CMD_ADDR,NAND_PGRM_END);

	NANDWaitRdy();
	NANDWaitRdyReg();
	return 0;
}

/* NAND Erase function */
Uint32 NANDEraseBlock(Uint32 blkAddr)
{
        Uint32 addr = blkAddr << (gNandInfo.blk_shift - gNandInfo.page_shift);
	NANDWriteByte(0, (void*)NAND_CMD_ADDR, NAND_BERASEC1);

	/* The block shift value varies for the x16 */
	NANDWriteByte(0, (void*)NAND_ALE_ADDR,(addr & 0xFF));
	NANDWriteByte(0, (void*)NAND_ALE_ADDR,(addr & 0xFF00)>>8);

	if(gNandInfo.addr_cycles == 4) {
		NANDWriteByte(0, (void*)NAND_ALE_ADDR,(addr & 0xFF0000)>>16);
	}

	NANDWriteByte(0, (void*)NAND_CMD_ADDR, NAND_BERASEC2);

	/* Add a delay */
	waitloop(10);

	/* Wait for device to get ready */
	while(NANDWaitRdy());
	while(NANDWaitRdyReg());

	return 0;
}

#endif /* UBL_USE_NAND_BOOT */

