;/*
; * Board specific setup info
; *
; * (C) Copyright 2003
; * Texas Instruments, <www.ti.com>
; * Kshitij Gupta <Kshitij@ti.com>
; *
; * Modified for OMAP 1610 H2 board by Nishant Kamat, Jan 2004
; *
; * Modified for OMAP 5912 OSK board by Rishi Bhattacharya, Apr 2004
; *
; * Modified for DV-EVM board by Rishi Bhattacharya, Apr 2005
; *
; * Modified for UBL board by Amit Chatterjee, Sept 2005
; *
; * Modified for UBL board by Amit Chatterjee, Feb 2006 for Turbo Mode
; *
; * Modified for Davinci HD by Nageswari, June 2007
; *
; * Modified for DaVinci HD by Kaustubh, February 2008
; *
; * Modified for DaVinci HD by Srirami Gangireddy, 23 APR 2008.
; * Corrected the DDR2 PSC clock enable function. Aslo moved SYSTEM PLL
; * initializaiton before DDR2 PLL initialization.
; * 
; * Modified for DaVinci HD by Hemant, 5 JUN 2009.
; * Moved PLL initialization code to C file. Added System PLL 
; * initialization to be able to overclock depending upon compilation 
; * flag.
; *
; * This program is free software; you can redistribute it and/or
; * modify it under the terms of the GNU General Public License as
; * published by the Free Software Foundation version 2.
; *
; * This program is distributed "as is" WITHOUT ANY WARRANTY of any
; * kind, whether express or implied; without even the implied warranty
; * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; * GNU General Public License for more details.
; */

	.state32
	.align 4
	.global _platformsetup
	.ref _platform_init

_platformsetup: .asmfunc

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * ++++++++++++++++++++++++ BASIC INITIALIZATION +++++++++++++++++++++++++++ *
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

    ; * mask all IRQs by setting all bits in the EINT default*
	MOV	r1, #0x00000000
	LDR	r0, EINT_ENABLE0
	STR	r1, [r0]
	LDR	r0, EINT_ENABLE1
	STR	r1, [r0]

    ;/* Put the GEM in reset; */
  	LDR R8, PSC_GEM_FLAG_CLEAR
	LDR R6, MDCTL_GEM
	LDR R7, [R6]
	AND R7, R7, R8
	STR R7, [R6]

    ;/* Enable the Power Domain Transition Command; */
	LDR R6, PTCMD_0
	LDR R7, [R6]
	ORR R7, R7, #0x2
	STR R7, [R6]

    ;/* Check for Transition Complete(PTSTAT); */
checkStatClkStopGem:
	LDR R6, PTSTAT_0
	LDR R7, [R6]
	AND R7, R7, #0x2
	CMP R7, #0x0
	BNE checkStatClkStopGem

    ;/* Check for GEM Reset Completion; */
checkGemStatClkStop:
	LDR R6, MDSTAT_GEM
	LDR R7, [R6]
	AND R7, R7, #0x100
	CMP R7, #0x0
	BNE checkGemStatClkStop

	NOP
	NOP

	;/* Do PLL and other init as applicable */
	SUB R13, R13, #0x4
	STR LR, [R13] 
	bl _platform_init
	LDR LR, [R13]
	ADD R13, R13, #0x4

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * +++++++++++++++++++ DDR2 LPSC ENABLE +++++++++++++++++++++++++++++++++++++*
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

    ;/* Set NEXT = 0x3 to enable DDR2 VCLK; */
  	LDR R8, PSC_FLAG_CLEAR	; 0xFFFFFFE0
	LDR R6, MDCTL_DDR2_0
	LDR R7, [R6]
	AND R7, R7, R8
	ORR R7, R7, #0x3
	STR R7, [R6]

    ;/* Enable the Power Domain Transition Command; */
	LDR R6, PTCMD_0
	LDR R7, [R6]
	ORR R7, R7, #0x1
	STR R7, [R6]

    ;/* Check for Transition Complete(PTSTAT); */
checkStatClkStop:
	LDR R6, PTSTAT_0
	LDR R7, [R6]
	AND R7, R7, #0x1
	CMP R7, #0x0
	BNE checkStatClkStop

    ;/* Check for DDR2 Controller Enable Completion; */
checkDDRStatClkStop:
	LDR R6, MDSTAT_DDR2_0
	LDR R7, [R6]
	AND R7, R7, #0x1F
	CMP R7, #0x3
	BNE checkDDRStatClkStop

	NOP
	NOP

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * +++++++++++++++++++ VTP CALIBRATION ++++++++++++++++++++++++++++++++++++++*
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

	;/* DDR VTP initialization */
	LDR R6, VTPIOCR
	LDR R7, VTPVAL1
	STR R7, [R6]

	LDR R6, VTPIOCR
	LDR R7, VTPVAL2
	STR R7, [R6]

    ;Wait for 40 VTP cycles or 80 ARM clock cycles.
	LDR R10, VTP_WAIT_VAL	
VTP_Complete:
	SUB R10, R10, #0x1
	CMP R10, #0x0
	BNE VTP_Complete

    ;/* Wait for DDR ready */
checkDdrReady:
	LDR R6, SDSTAT
	LDR R7, [R6]
	AND R7, R7, #0x4
	CMP R7, #0x4
	BNE checkDdrReady

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * +++++++++++++++++++ ISSUE SYNC RESET TO DDR2 MODULE +++++++++++++++++++++ *
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

;/* Shut down the DDR2 LPSC Module; */
	LDR R8, PSC_FLAG_CLEAR
	LDR R6, MDCTL_DDR2_0
	LDR R7, [R6]
	AND R7, R7, R8
	ORR R7, R7, #0x1
	STR R7, [R6]

    ;/* Enable the Power Domain Transition Command; */
	LDR R6, PTCMD_0
	LDR R7, [R6]
	ORR R7, R7, #0x1
	STR R7, [R6]

    ;/* Check for Transition Complete(PTSTAT); */
checkStatClkStop2:
	LDR R6, PTSTAT_0
	LDR R7, [R6]
	AND R7, R7, #0x1
	CMP R7, #0x0
	BNE checkStatClkStop2

    ;/* Check for DDR2 Controller Enable Completion; */
checkDDRStatClkStop2:
	LDR R6, MDSTAT_DDR2_0
	LDR R7, [R6]
	AND R7, R7, #0x1F
	CMP R7, #0x1
	BNE checkDDRStatClkStop2

	NOP
	NOP

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * +++++++++++++++++++ ENABLE DDR2 MODULE AGAIN +++++++++++++++++++++++++++++*
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

    ;/* Set NEXT = 0x3 to enable DDR2 VCLK; */
  	LDR R8, PSC_FLAG_CLEAR	; 0xFFFFFFE0
	LDR R6, MDCTL_DDR2_0
	LDR R7, [R6]
	AND R7, R7, R8
	ORR R7, R7, #0x3
	STR R7, [R6]

    ;/* Enable the Power Domain Transition Command; */
	LDR R6, PTCMD_0
	LDR R7, [R6]
	ORR R7, R7, #0x1
	STR R7, [R6]

    ;/* Check for Transition Complete(PTSTAT); */
checkStatClkStop3:
	LDR R6, PTSTAT_0
	LDR R7, [R6]
	AND R7, R7, #0x1
	CMP R7, #0x0
	BNE checkStatClkStop3

    ;/* Check for DDR2 Controller Enable Completion; */
checkDDRStatClkStop3:
	LDR R6, MDSTAT_DDR2_0
	LDR R7, [R6]
	AND R7, R7, #0x1F
	CMP R7, #0x3
	BNE checkDDRStatClkStop3
	
	NOP
	NOP

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * +++++++++++++++++ WAIT BEFORE PROGRAMING DDR2 TIMIMNG ++++++++++++++++++++*
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

    ;Wait for 10msec.
	LDR R10, DDR2_TIMING_WAIT_VAL	
DDR2TimingWait:
	SUB R10, R10, #0x1
	CMP R10, #0x0
	BNE DDR2TimingWait


;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * +++++++++++++++++ PROGRAM DDR2 MMRs FOR 297MHz SETTING ++++++++++++++++++ *
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

    ;/* Program PHY Control Register; */
	LDR R6, DDRCTL
	LDR R7, DDRCTL_VAL
	STR R7, [R6]

    ;/* Program SDRAM Bank Config Register; */
	LDR R6, SDCFG
	LDR R7, SDCFG_VAL
	STR R7, [R6]

    ;/* Program SDRAM TIM-0 Config Register; */
	LDR R6, SDTIM0
	LDR R7, SDTIM0_VAL_297MHz
	STR R7, [R6]

    ;/* Program SDRAM TIM-1 Config Register; */
	LDR R6, SDTIM1
	LDR R7, SDTIM1_VAL_297MHz
	STR R7, [R6]

    ;/* Program the SDRAM Bang Config Control Register; */
	LDR R10, MASK_VAL
	LDR R8, SDCFG
	LDR R9, SDCFG_VAL
	AND R9, R9, R10
	STR R9, [R8]

	LDR R6, SDREF
	LDR R7, SDREF_VAL
	STR R7, [R6]

	NOP
	NOP

    ;/* back to arch calling code; */
	MOV	pc,	lr
	.endasmfunc

;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*
; * ++++++++++++++++++++++ THE DATA USED BY THIS FILE  ++++++++++++++++++++++ *
;/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*

REG_TC_EMIFS_CONFIG:		;/* 32 bits; */
			.word 0xfffecc0c
REG_TC_EMIFS_CS0_CONFIG:	;/* 32 bits; */
			.word 0xfffecc10
REG_TC_EMIFS_CS1_CONFIG:	;/* 32 bits; */
			.word 0xfffecc14
REG_TC_EMIFS_CS2_CONFIG:	;/* 32 bits; */
			.word 0xfffecc18
REG_TC_EMIFS_CS3_CONFIG:	;/* 32 bits; */
			.word 0xfffecc1c

_PINMUX0:		.word 0x01C40000		;/* Device Configuration Registers; */
_PINMUX1:		.word 0x01C40004		;/* Device Configuration Registers; */

_DEV_SETTING:		.word 0x00000000

AEMIF_BASE_ADDR:	.word 0x20008000
WAITCFG:		.word 0x20008004
ACFG2:			.word 0x20008010
ACFG3:			.word 0x20008014
ACFG4:			.word 0x20008018
ACFG5:			.word 0x2000801C

WAITCFG_VAL:		.word 0x0
ACFG2_VAL:		.word 0x1
ACFG3_VAL:		.word 0x1
ACFG4_VAL:		.word 0x1
ACFG5_VAL:		.word 0x1

MDCTL_DDR2:		.word 0x01C41A34
PTCMD:			.word 0x01C41120
PTSTAT:			.word 0x01C41128
MDSTAT_DDR2:		.word 0x01C41834

MDCTL_TPCC:		.word 0x01C41A08
MDSTAT_TPCC:		.word 0x01C41808

MDCTL_TPTC0:		.word 0x01C41A0C
MDSTAT_TPTC0:		.word 0x01C4180C

MDCTL_TPTC1:		.word 0x01C41A10
MDSTAT_TPTC1:		.word 0x01C41810

DDR2DEBUG:		.word 0x8FFFF000

;/* EINT0 register; */
EINT_ENABLE0:		.word 0x01c48018

;/* EINT1 register; */
EINT_ENABLE1:		.word 0x01C4801C

CLEAR_FLAG:		.word 0xFFFFFFFF
EDMA_PARAM0_D_S_BIDX_VAL:
			.word 0x00010001
PSC_FLAG_CLEAR:		.word 0xFFFFFFE0
PSC_GEM_FLAG_CLEAR:	.word 0xFFFFFEFF
MDCTL_TPCC_SYNC:	.word 0x01C41A08
MDSTAT_TPCC_SYNC:	.word 0x01C41808

MDCTL_TPTC0_SYNC:	.word 0x01C41A0C
MDSTAT_TPTC0_SYNC:	.word 0x01C4180C

MDCTL_TPTC1_SYNC:	.word 0x01C41A10
MDSTAT_TPTC1_SYNC:	.word 0x01C41810

PTCMD_SYNC:		.word 0x01C41120
PTSTAT_SYNC:		.word 0x01C41128
DATA_MAX:		.word 0x0000FFFF
SPIN_ADDR:		.word 0x00003FFC   ;/* ARM PC value(B $) for the DSP Test cases; */
SPIN_OPCODE:		.word 0xEAFFFFFE

;/* Interrupt Clear Register; */
FIQ0_CLEAR:		.word 0x01C48000
FIQ1_CLEAR:		.word 0x01C48004
IRQ0_CLEAR:		.word 0x01C48008
IRQ1_CLEAR:		.word 0x01C4800C

;/* DDR2 MMR & CONFIGURATION VALUES for 75 MHZ; */
DDRCTL:			.word	0x200000E4
SDREF:			.word	0x2000000C
SDCFG:			.word	0x20000008
SDTIM0:			.word	0x20000010
SDTIM1:			.word	0x20000014
SDSTAT:			.word	0x20000004
VTPIOCR:		.word	0x200000F0  ;/* VTP IO Control register; */
DDRVTPR:		.word	0x01C42030  ;/* DDR VPTR MMR; */
DFT_ENABLE:		.word	0x01C4004C
VTP_MMR0:		.word	0x0000201F
VTP_MMR1:		.word	0x0000A01F
PCH_MASK:		.word	0x000003E0
VTP_LOCK_COUNT:		.word	0x000005B0
VTP_MASK:		.word	0xFFFFDFFF
VTP_RECAL:		.word	0x00040000
VTP_EN:			.word	0x00002000

CFGTEST:		.word	0x80010000

VTPVAL1:		.word 0x00000003
VTPVAL2:		.word 0x00000002
VTP_WAIT_VAL:	.word 0x000004B0

DDR2_TIMING_WAIT_VAL:	.word 990000

;/* 162MHz as per GEL file for DVEVM with Micron DDR2 SDRAM */
DDRCTL_VAL:		.word	0x00008AC7
SDREF_VAL:		.word   0x0000090D 		;for 297 MHz of DDR
SDCFG_VAL:		.word	0x08D78A32      ; /* CL=3 for MT47H64M16BT-5E */
MASK_VAL:		.word 	0xFF7F7FFF      ; 0x00000FFF
SDTIM0_VAL_297MHz:	.word	0x4B245C12	; (for 219MHz = 0X36DB42D1) (for 297MHz gel 0x4B245C12)

SDTIM1_VAL_297MHz:	.word	0x3B2BC742	; (for 219MHz = 0x001DC722) (for 297MHz = 0x0028C742)


;/* GEM Power Up & LPSC Control Register; */
CHP_SHRTSW:		.word	0x01C40038

PD1_CTL:		.word	0x01C41304
EPCPR:			.word	0x01C41070
EPCCR:			.word	0x01C41078
MDCTL_GEM:		.word	0x01C41A04
MDSTAT_GEM:		.word	0x01C41804
MDCTL_IMCOP:		.word	0x01C41AA0
MDSTAT_IMCOP:		.word	0x01C418A0

PTCMD_0:		.word	0x01C41120
PTSTAT_0:		.word	0x01C41128

P1394:			.word 0x01C41a20

MDCTL_DDR2_0:		.word 0x01C41A50
MDSTAT_DDR2_0:		.word 0x01C41850
DLLPWRUPMASK:		.word 0xFFFFFFEF
DDR2_ADDR:		.word 0x80000000

DFT_BASEADDR:		.word 0x01C42000
MMARG_BRF0:		.word 0x01C42010     ;/* BRF margin mode 0     (Read / write)*/
MMARG_G10:		.word 0x01C42018     ;/*GL margin mode 0      (Read / write)*/
MMARG_BRF0_VAL:		.word 0x00444400
DDR2_VAL:		.word 0x80000000
DUMMY_VAL:		.word 0xA55AA55A

; DaVinci SAFE operating frequencies to avoid multi-master lockup issues:
; PLL1								PLL2
; DSP		ARM			EDMA		DDR2
;(PLL1)		(PLL12)	(PLL13)	(PLL2)
; 486		243			162			162
; 432		216			144			144
; 405		202.5		135			135
; 378		189			126			126
