/*
 * platform_init.c
 * Board specific setup info
 *
 * Copyright (C) 2009 Texas Instruments Incorporated - http://www.ti.com/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation version 2.
 *
 * This program is distributed "as is" WITHOUT ANY WARRANTY of any
 * kind, whether express or implied; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#include <platform.h>

void loop(int loop_cnt)
{
	while(loop_cnt--);
}

void platform_init(void)
{
#ifdef UBL_PLL1_SETUP
	/* ---------------------------------------------------- *
	 * System PLL Intialization			        *
 	 * ---------------------------------------------------- *
	 */

	/* Set reference clock to internal oscillator */
	CSL_PLL1_REGS->PLLCTL &= PLL_CLKMODE_MASK;
	
	/* Bypass the PLL
	 * 	PreDiv, PLL, and PostDiv are bypassed. SYSCLK divided down
	 * 	directly from input reference clock refclk
	 */
	CSL_PLL1_REGS->PLLCTL &=  PLL_BYPASS_MASK;
	
	/* Wait for few cycles to allow PLLEN Mux switches properly to bypass Clock */
	loop(0x96);

	/* Reset the PLL */
	CSL_PLL1_REGS->PLLCTL |= PLL_RESET_MASK;

	/* Set the PLLDIS bit in PLLCTL to 1 (disable PLL output). */
	CSL_PLL1_REGS->PLLCTL |= PLLDIS;

	/* Power up the PLL */
	CSL_PLL1_REGS->PLLCTL &= PLL_PWRUP_MASK; 

	/* Enable the PLL from Disable Mode */
	CSL_PLL1_REGS->PLLCTL &= PLL_DISABLE_ENABLE_MASK;
	
	/* Wait for few cycles to allow PLLEN Mux switches properly to bypass Clock */
	loop(0x96);

	/* Program the PLL multiplier */
	CSL_PLL1_REGS->PLLM = CFG_PLL1_PLLM;

	CSL_PLL1_REGS->PLLDIV1 = PLL_1_DIV1_VAL;
	CSL_PLL1_REGS->PLLDIV2 = PLL_1_DIV2_VAL;
	CSL_PLL1_REGS->PLLDIV3 = PLL_1_DIV3_VAL;
	CSL_PLL1_REGS->PLLDIV4 = PLL_1_DIV4_VAL;
	CSL_PLL1_REGS->PLLDIV5 = PLL_1_DIV5_VAL;
	CSL_PLL1_REGS->PLLDIV6 = PLL_1_DIV6_VAL;
	CSL_PLL1_REGS->PLLDIV8 = PLL_1_DIV8_VAL;
	CSL_PLL1_REGS->PLLDIV9 = PLL_1_DIV9_VAL;

	/* Program the GOSET bit to take new divier values */
	CSL_PLL1_REGS->PLLCMD |= 0x1;

	/* Wait for Done */
	while (CSL_PLL1_REGS->PLLSTAT & 0x1);

	/* Wait for PLL to Reset Properly */
	loop(PLL_RESET_COUNT);

	/* Bring PLL out of Reset */
	CSL_PLL1_REGS->PLLCTL &= ~PLL_RESET_MASK;
     	
	/* Wait for PLL to Lock */
	loop(PLL_LOCK_COUNT);

	/* Enable the PLL */
	CSL_PLL1_REGS->PLLCTL |= 0x1;

#endif /* UBL_PLL1_SETUP */

	/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *
	 * ++++++++++++++++++++++++ DDR2 PLL INITIALIZATION +++++++++++++++++ *
	 * ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ *
	 */
	
	/* Set reference clock to internal oscillator */
	CSL_PLL2_REGS->PLLCTL &= PLL_CLKMODE_MASK;

	/* Before changing the PLL frequency, switch to PLL bypass mode:
	 * a. Clear the PLLENSRC bit in PLLCTL to 0 to allow PLLCTL.PLLEN to
	 * take effect.
	 */
	CSL_PLL2_REGS->PLLCTL &= CLR_PLLEN_SRC;

	/* b. Clear the PLLEN bit in PLLCTL to 0 (select PLL bypass mode). */
	CSL_PLL2_REGS->PLLCTL &= CLR_PLLEN;

	/* c. Wait for 40 MXI clock cycles to ensure PLLC switches to bypass
	 * mode properly.
	 */
	loop(0x258);

	/* 3. Set the PLLRST bit in PLLCTL to 1 (reset PLL). */
	CSL_PLL2_REGS->PLLCTL |= PLL_RESET_MASK;

	/* 4. Set the PLLDIS bit in PLLCTL to 1 (disable PLL output). */
	CSL_PLL2_REGS->PLLCTL |= PLLDIS;

	/* 5. Clear the PLLPWRDN bit in PLLCTL to 0 to bring the PLL out of
	 * power-down mode.
	 */
	CSL_PLL2_REGS->PLLCTL &= PLL_PWRUP_MASK;

	/* 6. Clear the PLLDIS bit in PLLCTL to 0 (enable the PLL) to allow PLL
	 * outputs to start toggling.
	 */
	CSL_PLL2_REGS->PLLCTL &= PLL_DISABLE_ENABLE_MASK;

	/* 7. Wait for PLL stabilization time. (4096 MXI clock cycles) */
	loop(0xF000);

	/* 8. Program the required multiplier value in the PLL multiplier
	 * control register (PLLM).
	 */
	CSL_PLL2_REGS->PLLM = CFG_PLL2_PLLM;

	/* 9. If necessary, program the PLL controller divider 1 register
	 * (PLLDIV1) to change the SYSCLK1 divide value
	 * a. Program the RATIO field in PLLDIV1 with the desired divide factor
	 */
	CSL_PLL2_REGS->PLLDIV1 = PLL_2_DIV1_VAL;

	/* b. Set the GOSET bit in PLLCMD to 1 to initiate a new divider
	 * transition.
	 */
	CSL_PLL2_REGS->PLLCMD |= 0x1;

	/* c. Wait for the GOSTAT bit in the PLL controller status register
	 * (PLLSTAT) to clear to 0 (completion of phase alignment)
	 */
	while (CSL_PLL2_REGS->PLLSTAT & 0x1);

	/* 10. Wait for PLL to reset properly. The PLL reset time is a minimum
	 * of 500 MXI clock cycles.
	 */
	loop(PLL_RESET_COUNT);
	
	/* 11. Clear the PLLRST bit in PLLCTL to 0 to bring the PLL out of
	 * reset.
	 */
	CSL_PLL2_REGS->PLLCTL &= ~PLL_RESET_MASK;

	/* 12. Wait for 3100 MXI clock or reference clock cycles to allow PLL to
	 * lock.
	 */
	loop(PLL_LOCK_COUNT);

	/* 13. Set the PLLEN bit in PLLCTL to 1 to remove the PLL from bypass
	 * mode.
	 */
	CSL_PLL2_REGS->PLLCTL |= 0x1;

	return;
}
